=== modified file 'magentoerpconnect/delivery.py'
--- magentoerpconnect/delivery.py	2011-11-04 13:41:02 +0000
+++ magentoerpconnect/delivery.py	2012-03-15 09:47:04 +0000
@@ -25,18 +25,46 @@
 class delivery_carrier(osv.osv):
     _inherit = "delivery.carrier"
 
+    def _carrier_code(self, cr, uid, ids, name, args, context=None):
+        res = {}
+        for carrier in self.browse(cr, uid, ids, context=context):
+            if not carrier.magento_code:
+                res[carrier.id] = False
+                continue
+            res[carrier.id] = carrier.magento_code.split('_')[0]
+        return res
+
     _columns = {
         'magento_code': fields.char('Magento Carrier Code', size=64, required=False),
         'magento_tracking_title': fields.char('Magento Tracking Title', size=64, required=False),
+        # in Magento, the delivery method is something like that:
+        # tntmodule2_tnt_basic
+        # where the first part before the _ is always the carrier code
+        # in this example, the carrier code is tntmodule2
+        'magento_carrier_code':
+            fields.function(_carrier_code,
+                            string='Magento Base Carrier Code',
+                            size=32,
+                            type='char')
     }
-    
-    def check_ext_carrier_reference(self, cr, uid, id, magento_incrementid, context=None):
+
+    def check_ext_carrier_reference(self, cr, uid, id,
+                                    magento_incrementid, context=None):
         if context is None: context = {}
         conn = context.get('conn_obj', False)
-        mag_carrier = conn.call('sales_order_shipment.getCarriers', [magento_incrementid])
-        carrier = self.read(cr, uid, id, ['magento_code', 'name'], context=context)
-        if not carrier['magento_code'] in mag_carrier.keys():
-            raise osv.except_osv(_("Error"), _("The carrier %s don't have a magento_code valid!! Indeed the value %s is not in the magento carrier list %s" %(carrier['name'], carrier['magento_code'], mag_carrier.keys())))
+        mag_carrier = conn.call(
+            'sales_order_shipment.getCarriers', [magento_incrementid])
+        carrier = self.read(
+            cr, uid, id, ['magento_carrier_code', 'name'], context=context)
+        if not carrier['magento_carrier_code'] in mag_carrier.keys():
+            raise osv.except_osv(
+                _("Error"),
+                _("The carrier %s doesn't have a magento_code valid !"
+                  "The value %s is not in the carrier list %s "
+                  "allowed by Magento") %
+                (carrier['name'],
+                 carrier['magento_carrier_code'],
+                 mag_carrier.keys()))
         return True
 delivery_carrier()
 

=== modified file 'magentoerpconnect/partner.py'
--- magentoerpconnect/partner.py	2012-01-10 13:06:02 +0000
+++ magentoerpconnect/partner.py	2012-03-27 09:40:33 +0000
@@ -6,7 +6,7 @@
 #                                                                       #
 # Copyright (C) 2009  Sharoon Thomas, Raphaël Valyi                     #
 # Copyright (C) 2011 Akretion Sébastien BEAU sebastien.beau@akretion.com#
-# Copyright (C) 2011 Camptocamp Guewen Baconnier                        # 
+# Copyright (C) 2011-2012 Camptocamp Guewen Baconnier                   #
 #                                                                       #
 #This program is free software: you can redistribute it and/or modify   #
 #it under the terms of the GNU General Public License as published by   #
@@ -28,7 +28,7 @@
 
 class res_partner_category(magerp_osv.magerp_osv):
     _inherit = "res.partner.category"
-    
+
     _columns = {
                     'tax_class_id':fields.integer('Tax Class ID'),
                 }
@@ -36,7 +36,7 @@
 
 class res_partner_address(magerp_osv.magerp_osv):
     _inherit = "res.partner.address"
-    
+
     _columns = {
                     'firstname':fields.char('First Name', size=100),
                     'lastname':fields.char('Last Name', size=100),
@@ -44,7 +44,7 @@
                 }
     _defaults = {
                     'is_magento_order_address': lambda * a:False,
-                 }    
+                 }
 res_partner_address()
 
 class res_partner(magerp_osv.magerp_osv):

=== modified file 'magentoerpconnect/product.py'
--- magentoerpconnect/product.py	2012-03-14 14:04:39 +0000
+++ magentoerpconnect/product.py	2012-03-29 06:11:58 +0000
@@ -22,9 +22,8 @@
 #along with this program.  If not, see <http://www.gnu.org/licenses/>.  #
 #########################################################################
 
-from osv import osv, fields
+from osv import osv, orm, fields
 import datetime
-import base64
 import time
 import pooler
 import magerp_osv
@@ -33,6 +32,7 @@
 import unicodedata
 import base64, urllib
 import os
+from lxml import etree
 
 from tools import DEFAULT_SERVER_DATETIME_FORMAT
 
@@ -749,87 +749,129 @@
         '''this empty function will save the magento field'''
         return {'type': 'ir.actions.act_window_close'}
 
-    def redefine_prod_view(self,cr,uid, field_names, context=None):
-        def clean_for_xml(string):
-            for key, key_replace in [('&', '&amp;'), ('>','&gt;'),  ('<', '&lt;')]:
-                string = string.replace(key, key_replace)
-            return string
-        #This function will rebuild the view for product from instances, attribute groups etc
-        #Get all objects needed
-        #inst_obj = self.pool.get('external.referential')
+    def redefine_prod_view(self, cr, uid, field_names, context=None):
+        """
+        Rebuild the product view with attribute groups and attributes
+        """
         if context is None: context = {}
         attr_set_obj = self.pool.get('magerp.product_attribute_set')
         attr_group_obj = self.pool.get('magerp.product_attribute_groups')
         attr_obj = self.pool.get('magerp.product_attributes')
         translation_obj = self.pool.get('ir.translation')
-        xml = u"<notebook colspan='4'>\n"
-        attr_grp_ids = attr_group_obj.search(cr,uid,[])
-        attr_groups = attr_group_obj.browse(cr,uid,attr_grp_ids)
+
         attribute_set_id = context['set']
         attr_set = attr_set_obj.browse(cr, uid, attribute_set_id)
         attr_group_fields_rel = {}
-        cr.execute("select attr_id, group_id, attribute_code, frontend_input, frontend_label, is_required, apply_to, field_name  from magerp_attrset_attr_rel left join magerp_product_attributes on magerp_product_attributes.id = attr_id where magerp_attrset_attr_rel.set_id=%s" % attribute_set_id)
-        results = cr.fetchall()
-        result = results.pop()
-        while len(results) > 0:
-            mag_group_id = result[1]
-            oerp_group_id = attr_group_obj.extid_to_oeid(cr, uid, mag_group_id, attr_set.referential_id.id)
-            if not oerp_group_id: #FIXME workaround in multi-Magento instances (databases) where attribute group might not be found due to the way we share attributes currently
-                for ref_id in self.pool.get('external.referential').search(cr, uid, []):
+
+        multiwebsites = context.get('multiwebsite', False)
+
+        fields_get = self.fields_get(cr, uid, field_names, context)
+
+        cr.execute("select attr_id, group_id, attribute_code, frontend_input, "
+                   "frontend_label, is_required, apply_to, field_name "
+                   "from magerp_attrset_attr_rel "
+                   "left join magerp_product_attributes "
+                   "on magerp_product_attributes.id = attr_id "
+                   "where magerp_attrset_attr_rel.set_id=%s" %
+                   attribute_set_id)
+
+        results = cr.dictfetchall()
+        attribute = results.pop()
+        while results:
+            mag_group_id = attribute['group_id']
+            oerp_group_id = attr_group_obj.extid_to_oeid(
+                cr, uid, mag_group_id, attr_set.referential_id.id)
+            # FIXME: workaround in multi-Magento instances (databases)
+            # where attribute group might not be found due to the way we
+            # share attributes currently
+            if not oerp_group_id:
+                ref_ids = self.pool.get(
+                    'external.referential').search(cr, uid, [])
+                for ref_id in ref_ids:
                      if ref_id != attr_set.referential_id.id:
-                         oerp_group_id = attr_group_obj.extid_to_oeid(cr, uid, mag_group_id, ref_id)
+                         oerp_group_id = attr_group_obj.extid_to_oeid(
+                             cr, uid, mag_group_id, ref_id)
                          if oerp_group_id:
                              break
-            group_name = attr_group_obj.read(cr, uid, oerp_group_id, ['attribute_group_name'])['attribute_group_name']
+
+            group_name = attr_group_obj.read(
+                cr, uid, oerp_group_id,
+                ['attribute_group_name'],
+                context=context)['attribute_group_name']
             
-            #Create a page for the attribute group
-            if not attr_group_fields_rel.get(group_name, False):
-                attr_group_fields_rel[group_name] = []
+            # Create a page for each attribute group
+            attr_group_fields_rel.setdefault(group_name, [])
             while True:
-                field_xml=""
-                if result[1] != mag_group_id:
+                if attribute['group_id'] != mag_group_id:
                     break
-                if result[7] in field_names:
-                    if not result[2] in attr_obj._no_create_list:
-                        if result[3] in ['textarea']:
-                            trans = translation_obj._get_source(cr, uid, 'product.product', 'view', context.get('lang', ''), result[4])
-                            trans = trans or result[4]
-                            field_xml+="<newline/><separator colspan='4' string='%s'/>" % (clean_for_xml(trans),)
-                        field_xml+="<field name='" +  clean_for_xml(result[7]) + "'"
-                        if result[5] and (result[6] == "" or "simple" in result[6] or "configurable" in result[6]) and result[2] not in self._magento_fake_mandatory_attrs:
-                            field_xml+=""" attrs="{'required':[('magento_exportable','=',True)]}" """
-                        if result[3] in ['textarea']:
-                            field_xml+=" colspan='4' nolabel='1' " 
-                        field_xml+=" />\n"
-                        if (group_name in  [
-                                            u'Meta Information', 
-                                            u'General', 
-                                            u'Custom Layout Update', 
-                                            u'Prices', 
-                                            u'Design', 
-                                            ]) or GROUP_CUSTOM_ATTRS_TOGETHER==False:
-                            attr_group_fields_rel[group_name].append(field_xml)
+
+                if attribute['field_name'] in field_names:
+                    if not attribute['attribute_code'] in attr_obj._no_create_list:
+                        if (group_name in  ['Meta Information',
+                                            'General',
+                                            'Custom Layout Update',
+                                            'Prices',
+                                            'Design']) or \
+                           GROUP_CUSTOM_ATTRS_TOGETHER==False:
+                            attr_group_fields_rel[group_name].append(attribute)
                         else:
-                            custom_attributes = attr_group_fields_rel.get(u"Custom Attributes",[])
-                            custom_attributes.append(field_xml)
-                            attr_group_fields_rel[u"Custom Attributes"] = custom_attributes
-                if len(results) > 0:
-                    result = results.pop()
+                            attr_group_fields_rel.setdefault(
+                                'Custom Attributes', []).append(attribute)
+                if results:
+                    attribute = results.pop()
                 else:
                     break
+
+        notebook = etree.Element('notebook', colspan="4")
+
         attribute_groups = attr_group_fields_rel.keys()
         attribute_groups.sort()
-        for each_attribute_group in attribute_groups:
-            trans = translation_obj._get_source(cr, uid, 'product.product', 'view', context.get('lang', ''), each_attribute_group)
-            trans = trans or each_attribute_group
-            if attr_group_fields_rel.get(each_attribute_group,False):
-                xml+="<page string='" + clean_for_xml(trans) + "'>\n<group colspan='4' col='4'>"
-                xml+="\n".join(attr_group_fields_rel.get(each_attribute_group,[]))
-                xml+="</group></page>\n"
-        if context.get('multiwebsite', False):
-            xml+="""<page string='Websites'>\n<field name='websites_ids' nolabel="1"/>\n</page>\n"""
-        xml+="</notebook>"
-        return xml
+        for group in attribute_groups:
+            lang = context.get('lang', '')
+            trans = translation_obj._get_source(
+                cr, uid, 'product.product', 'view', lang, group)
+            trans = trans or group
+            if attr_group_fields_rel.get(group):
+                page = etree.SubElement(notebook, 'page', string=trans)
+                for attribute in attr_group_fields_rel.get(group, []):
+                    if attribute['frontend_input'] == 'textarea':
+                        etree.SubElement(page, 'newline')
+                        etree.SubElement(
+                            page,
+                            'separator',
+                            colspan="4",
+                            string=fields_get[attribute['field_name']]['string'])
+
+                    f = etree.SubElement(
+                        page, 'field', name=attribute['field_name'])
+
+                    # apply_to is a string like
+                    # "simple,configurable,virtual,bundle,downloadable"
+                    req_apply_to = attribute['apply_to'] == '' or \
+                        'simple' in attribute['apply_to'] or \
+                        'configurable' in attribute['apply_to']
+                    if attribute['is_required'] and \
+                       req_apply_to and \
+                        attribute['attribute_code'] not in self._magento_fake_mandatory_attrs:
+                        f.set('attrs', "{'required': [('magento_exportable', '=', True)]}")
+
+                    if attribute['frontend_input'] == 'textarea':
+                        f.set('nolabel', "1")
+                        f.set('colspan', "4")
+
+                    orm.setup_modifiers(
+                        f, fields_get[attribute['field_name']],
+                        context=context)
+
+        if multiwebsites:
+            website_page = etree.SubElement(
+                notebook, 'page', string=_('Websites'))
+            wf = etree.SubElement(
+                website_page, 'field', name='websites_ids', nolabel="1")
+            orm.setup_modifiers(
+                wf, fields_get['websites_ids'], context=context)
+
+        return notebook
     
     def _filter_fields_to_return(self, cr, uid, field_names, context=None):
         '''This function is a hook in order to filter the fields that appears on the view'''
@@ -838,48 +880,91 @@
     def fields_view_get(self, cr, uid, view_id=None, view_type='form', context=None, toolbar=False, submenu=False):
         if context is None:
             context = {}
-
-        result = super(product_mag_osv, self).fields_view_get(cr, uid, view_id,view_type,context,toolbar=toolbar)
+        result = super(product_mag_osv, self).fields_view_get(
+            cr, uid, view_id,view_type,context,toolbar=toolbar)
         if view_type == 'form':
-            result['arch'] = result['arch'].decode('utf8') #in order to support special character, the arch for the product view will be a unicode and not a str
-            if context.get('set', False):
+            eview = etree.fromstring(result['arch'])
+            btn = eview.xpath("//button[@name='open_magento_fields']")
+            if btn:
+                btn = btn[0]
+            page_placeholder = eview.xpath(
+                "//page[@string='attributes_placeholder']")
+
+            attrs_mag_notebook = "{'invisible': [('set', '=', False)]}"
+
+            if context.get('set'):
+                fields_obj = self.pool.get('ir.model.fields')
                 models = ['product.template']
                 if self._name == 'product.product':
                     models.append('product.product')
-                ir_model_ids = self.pool.get('ir.model').search(cr, uid, [('model', 'in', models)])
-                ir_model_field_ids = self.pool.get('ir.model.fields').search(cr, uid, [('model_id', 'in', ir_model_ids)])
+
+                model_ids = self.pool.get('ir.model').search(
+                    cr, uid, [('model', 'in', models)], context=context)
+                field_ids = fields_obj.search(
+                    cr, uid,
+                    [('model_id', 'in', model_ids)],
+                    context=context)
                 field_names = ['product_type']
-                for field in self.pool.get('ir.model.fields').browse(cr, uid, ir_model_field_ids):
+                fields = fields_obj.browse(cr, uid, field_ids, context=context)
+                for field in fields:
                     if field.name.startswith('x_'):
                         field_names.append(field.name)
-                if len(self.pool.get('external.shop.group').search(cr,uid,[('referential_type', 'ilike', 'mag')])) >1 :
+                website_ids = self.pool.get('external.shop.group').search(
+                    cr, uid,
+                    [('referential_type', '=ilike', 'mag%')],
+                    context=context)
+                if len(website_ids) > 1:
                     context['multiwebsite'] = True
                     field_names.append('websites_ids')
-                    
-                field_names = self._filter_fields_to_return(cr, uid, field_names, context)
-                result['fields'].update(self.fields_get(cr, uid, field_names, context))
-
-                view_part = self.redefine_prod_view(cr, uid, field_names, context)
-                if '<page string="attributes_placeholder"/>' in result['arch']:
-                    # If the view have the tag '<page string="attributes_placeholder"/>' the view asked is the main view
-                    # Else it's the pop up with specific fields
-                    magento_tab = (
-                        "<page string='" + _('Magento Information') + " ' attrs=\"{'invisible':[('magento_exportable','!=',1)]}\">"
-                            "<field name='product_type' attrs=\"{'required':[('magento_exportable','=',True)]}\"/>\n"
-                            + view_part +
-                        "</page>"
-                        )
-                    result['arch'] = result['arch'].replace('<page string="attributes_placeholder"/>', magento_tab)
-                    result['arch'] = result['arch'].replace('<button name="open_magento_fields"/>', '')
+
+                field_names = self._filter_fields_to_return(
+                    cr, uid, field_names, context)
+                result['fields'].update(
+                    self.fields_get(cr, uid, field_names, context))
+
+                attributes_notebook = self.redefine_prod_view(
+                                    cr, uid, field_names, context)
+
+                # if the placeholder is a "page", that means we are
+                # in the product main form. If it is a "separator", it
+                # means we are in the attributes popup
+                if page_placeholder:
+                    placeholder = page_placeholder[0]
+                    magento_page = etree.Element(
+                        'page',
+                        string=_('Magento Information'),
+                        attrs=attrs_mag_notebook)
+                    orm.setup_modifiers(magento_page, context=context)
+                    f = etree.SubElement(
+                        magento_page,
+                        'field',
+                        name='product_type',
+                        attrs="{'required': [('magento_exportable', '=', True)]}")
+                    orm.setup_modifiers(
+                        f, field=result['fields']['product_type'], context=context)
+                    magento_page.append(attributes_notebook)
+                    btn.getparent().remove(btn)
                 else:
-                    result['arch'] = result['arch'].replace('<separator string="attributes_placeholder" colspan="4"/>', view_part)
+                    placeholder = eview.xpath(
+                        "//separator[@string='attributes_placeholder']")[0]
+                    magento_page = attributes_notebook
+
+                placeholder.getparent().replace(placeholder, magento_page)
             else:
-                magento_button = (
-                    "<button name='open_magento_fields' string='Open Magento Fields' icon='gtk-go-forward' type='object'"
-                    " colspan='2' attrs=\"{'invisible':[('magento_exportable','!=', True)]}\"/>"
-                    )
-                result['arch'] = result['arch'].replace('<button name="open_magento_fields"/>', magento_button)
-                result['arch'] = result['arch'].replace('<page string="attributes_placeholder"/>', "")
+                new_btn = etree.Element(
+                    'button',
+                    name='open_magento_fields',
+                    string=_('Open Magento Fields'),
+                    icon='gtk-go-forward',
+                    type='object',
+                    colspan='2',
+                    attrs=attrs_mag_notebook)
+                orm.setup_modifiers(new_btn, context=context)
+                btn.getparent().replace(btn, new_btn)
+                placeholder = page_placeholder[0]
+                placeholder.getparent().remove(placeholder)
+
+            result['arch'] = etree.tostring(eview, pretty_print=True)
         return result
 
 class product_template(product_mag_osv):
@@ -1127,9 +1212,8 @@
        
         return product_data
 
-    def oevals_from_extdata(self, cr, uid, external_referential_id, data_record, key_field, mapping_lines, defaults, context):
-        res = super(product_product, self).oevals_from_extdata(cr, uid, external_referential_id, data_record, key_field, mapping_lines, defaults, context)
-
+    def oevals_from_extdata(self, cr, uid, external_referential_id, data_record, mapping_lines, key_for_external_id=None, parent_data=None, previous_lines=None, defaults=None, context=None):
+        res = super(product_product, self).oevals_from_extdata(cr, uid, external_referential_id, data_record, mapping_lines, key_for_external_id=key_for_external_id, parent_data=parent_data, previous_lines=previous_lines, defaults=defaults, context=context)
         # assign a default product type (Procurement, not the magento's one)
         if not res.get('type'):
             magerp_type_obj = self.pool.get('magerp.product_product_type')
@@ -1169,15 +1253,16 @@
             bom_ids = self.read(cr, uid, id, ['bom_ids'])['bom_ids']
             if len(bom_ids): # it has or is part of a BoM
                 cr.execute("SELECT product_id, product_qty FROM mrp_bom WHERE bom_id = %s", (bom_ids[0],)) #FIXME What if there is more than a materials list?
-                results = cr.fetchall()
+                results = cr.dictfetchall()
                 child_ids = []
                 quantities = {}
-                for x in results:
-                    child_ids += [x[0]]
-                    sku = self.read(cr, uid, x[0], ['magento_sku'])['magento_sku']
-                    quantities.update({sku: x[1]})
+                for row in results:
+                    child_ids.append(row['product_id'])
+                    quantities.update({row['product_id']: row['product_qty']})
                 if child_ids: #it is an assembly and it contains the products child_ids: 
                     self.ext_export(cr, uid, child_ids, external_referential_ids, defaults, context) #so we export them
+            else:
+                return False
         else:
             logger.notifyChannel('ext synchro', netsvc.LOG_ERROR, "OpenERP 'grouped' products will export to Magento as 'grouped products' only if they have a BOM and if the 'mrp' BOM module is installed")
         return quantities, child_ids
@@ -1286,7 +1371,7 @@
             child_ids = []
             product_type = self.read(cr, uid, id, ['product_type'])['product_type']
             if product_type == 'grouped': # lookup for Magento "grouped product"
-                quantities, childs_ids = self.action_before_exporting_grouped_product(cr, uid, id, external_referential_ids, defaults, context)
+                quantities, child_ids = self.action_before_exporting_grouped_product(cr, uid, id, external_referential_ids, defaults, context)
             
             self.action_before_exporting(cr, uid, id, product_type, external_referential_ids, defaults, context=context)
             
@@ -1398,7 +1483,7 @@
                 for link in product.product_link_ids:
                     if link.type == link_type:
                         linked_product_ids.append(link.linked_product_id.id)
-                        position[link.linked_product_id.magento_sku] = link.sequence
+                        position[link.linked_product_id.id] = link.sequence
                 self.ext_product_assign(cr, uid, link_type, product.id, linked_product_ids, position=position,
                                         external_referential_ids=external_referential_ids, defaults=defaults, context=context)
         return True
@@ -1411,43 +1496,77 @@
         logger = netsvc.Logger()
         conn = context.get('conn_obj', False)
 
-        # ensure that the product to link is exported before assigning it, export it if necessary
-        for external_referential_id in external_referential_ids:
+        for ref_id in external_referential_ids:
+            # ensure that the product to link is exported before assigning it,
+            # export it if necessary
             ids_to_export = []
             for child_id in child_ids:
-                if not self.oeid_to_extid(cr, uid, child_id, external_referential_id, context=context):
+                if not self.oeid_to_extid(cr, uid, child_id, ref_id, context=context):
                     ids_to_export.append(child_id)
             export_ctx = context.copy()
             export_ctx['force_export'] = True
-            self.ext_export(cr, uid, ids_to_export, [external_referential_id], defaults, export_ctx)
-
-        parent_sku = self.read(cr, uid, parent_id, ['magento_sku'])['magento_sku']
-        new_child_skus = self.read(cr, uid, child_ids, ['magento_sku']) # get the sku of the products to be assigned
-        new_child_skus = [x['magento_sku'] for x in new_child_skus]
-        
-        data = [type, parent_sku]
-        child_list = conn.call('product_link.list', data) # get the sku of the products already assigned
-        old_child_skus = [x['sku'] for x in child_list]
-        skus_to_remove = []
-        skus_to_assign = []
-        skus_to_update = []
-        for old_child_sku in old_child_skus:
-            if old_child_sku not in new_child_skus:
-                skus_to_remove += [old_child_sku]
-        for new_child_sku in new_child_skus:
-            if new_child_sku in old_child_skus:
-                skus_to_update += [new_child_sku]
-            else:
-                skus_to_assign += [new_child_sku]
-        for old_child_sku in skus_to_remove:
-            conn.call('product_link.remove', data + [old_child_sku]) # remove the products that are no more used
-            logger.notifyChannel('ext assign', netsvc.LOG_INFO, "Successfully removed assignment of type %s for product %s to product %s" % (type, parent_sku, old_child_sku))
-        for child_sku in skus_to_assign:
-            conn.call('product_link.assign', data + [child_sku, {'position': position.get(child_sku, 0), 'qty': quantities.get(child_sku, 1)}]) # assign new product
-            logger.notifyChannel('ext assign', netsvc.LOG_INFO, "Successfully assigned product %s to product %s with type %s" %(parent_sku, child_sku, type))
-        for child_sku in skus_to_update:
-            conn.call('product_link.update', data + [child_sku, {'position': position.get(child_sku, 0), 'qty': quantities.get(child_sku, 1)}]) # update products already assigned
-            logger.notifyChannel('ext assign', netsvc.LOG_INFO, "Successfully updated assignment of type %s of product %s to product %s" %(type, parent_sku, child_sku))
+            self.ext_export(
+                cr, uid, ids_to_export, [ref_id], defaults=defaults, context=export_ctx)
+
+            ext_id = self.oeid_to_extid(
+                cr, uid, parent_id, ref_id, context=context)
+            if not ext_id:
+                continue
+
+            # get the sku of the products already assigned
+            magento_args = [type, ext_id]
+
+            # magento existing children ids
+            child_list = conn.call('product_link.list', magento_args)
+            old_child_ext_ids = [x['product_id'] for x in child_list]
+
+            ext_id_to_remove = []
+            ext_id_to_assign = []
+            ext_id_to_update = []
+
+            # list of children setup on openerp
+            new_child_ext_ids = dict([(self.oeid_to_extid(cr, uid, child_id, ref_id, context=context),
+                                       child_id)
+                                      for child_id in child_ids])
+
+            skus = dict([(p.id, p.magento_sku)
+                    for p in
+                    self.browse(
+                        cr, uid, child_ids + [parent_id], context=context)])
+
+            # compute the diff between openerp and magento
+            for c_ext_id in old_child_ext_ids:
+                if c_ext_id not in new_child_ext_ids:
+                    ext_id_to_remove.append(c_ext_id)
+            for c_ext_id in new_child_ext_ids.keys():
+                if c_ext_id in old_child_ext_ids:
+                    ext_id_to_update.append(c_ext_id)
+                else:
+                    ext_id_to_assign.append(c_ext_id)
+
+            # calls to magento to delete, create or update the links
+            for c_ext_id in ext_id_to_remove:
+                 # remove the product links that are no more setup on openerp
+                conn.call('product_link.remove', magento_args + [c_ext_id])
+                logger.notifyChannel('ext assign', netsvc.LOG_INFO, "Successfully removed assignment of type %s for product %s to product %s" % (type, skus[parent_id], c_ext_id))
+            for child_ext_id in ext_id_to_assign:
+                # assign new product links
+                product_id = new_child_ext_ids[child_ext_id]
+                conn.call('product_link.assign',
+                          magento_args +
+                          [child_ext_id,
+                              {'position': position.get(product_id, 0),
+                               'qty': quantities.get(product_id, 1)}])
+                logger.notifyChannel('ext assign', netsvc.LOG_INFO, "Successfully assigned product %s to product %s with type %s" %(skus[parent_id], skus[product_id], type))
+            for child_ext_id in ext_id_to_update:
+                # update products links already assigned
+                product_id = new_child_ext_ids[child_ext_id]
+                conn.call('product_link.update',
+                          magento_args +
+                          [child_ext_id,
+                              {'position': position.get(product_id, 0),
+                               'qty': quantities.get(product_id, 1)}])
+                logger.notifyChannel('ext assign', netsvc.LOG_INFO, "Successfully updated assignment of type %s of product %s to product %s" %(type, skus[parent_id], skus[product_id]))
         return True
 
     #TODO move this code (get exportable image) and also some code in product_image.py and sale.py in base_sale_multichannel or in a new module in order to be more generic

=== modified file 'magentoerpconnect/product_view.xml'
--- magentoerpconnect/product_view.xml	2012-01-25 16:35:35 +0000
+++ magentoerpconnect/product_view.xml	2012-03-28 09:58:18 +0000
@@ -243,7 +243,7 @@
 						<field name="magento_sku" select="2" attrs="{'required':[('magento_exportable','==',True)], 'readonly':[('magento_exported', '==', True)]}"/>
 					</xpath>
 					<xpath expr="/form/group/group/field[@name='variants']" position="after">
-						<field name="set" select="2" attrs="{'required':[('magento_exportable','==',True)]}"/>
+						<field name="set" select="2" attrs="{'required':[('magento_exportable','==',True)], 'readonly': [('magento_exported', '=', True)]}"/>
 					</xpath>
 					<xpath expr="/form/group/group/field[@name='sale_ok']" position="before">
 						<button name="open_magento_fields"/>
@@ -277,10 +277,11 @@
                     <group colspan='4' col='8'>
                         <separator string="Magento Information" colspan="8"/>
                         <field name="name"/>
-                        <field name="set" select="2" attrs="{'required':[('magento_exportable','==',True)]}"/>
+                        <field name="set" select="2" attrs="{'required':[('magento_exportable','==',True)], 'readonly': [('magento_exported', '=', True)]}"/>
                         <field name="magento_sku" select="2" attrs="{'required':[('magento_exportable','==',True)]}"/>
                         <field name="product_type" select="2" attrs="{'required':[('magento_exportable','==',True)]}"/>
                         <field name="magento_exportable"/>
+                        <field name="magento_exported" invisible="1" />
                     </group>
                     <separator string="attributes_placeholder" colspan="4"/>
                     <group colspan='4' col='4'>

=== modified file 'magentoerpconnect/sale.py'
--- magentoerpconnect/sale.py	2012-03-12 09:55:45 +0000
+++ magentoerpconnect/sale.py	2012-03-29 06:11:58 +0000
@@ -6,7 +6,7 @@
 # Copyright (C) 2011  Sharoon Thomas                                    #
 # Copyright (C) 2009  Raphaël Valyi                                     #
 # Copyright (C) 2011 Akretion Sébastien BEAU sebastien.beau@akretion.com#
-# Copyright (C) 2011 Camptocamp Guewen Baconnier                        #
+# Copyright (C) 2011-2012 Camptocamp Guewen Baconnier                   #
 #                                                                       #
 #This program is free software: you can redistribute it and/or modify   #
 #it under the terms of the GNU General Public License as published by   #
@@ -27,7 +27,6 @@
 import magerp_osv
 import netsvc
 from tools.translate import _
-from collections import defaultdict
 import string
 #from datetime import datetime
 import tools
@@ -160,8 +159,8 @@
         return result
 
     def check_need_to_update(self, cr, uid, ids, context=None):
-        '''This function will update the order status in OpenERP for the order which are in the state 'need to update' '''
-        logger = netsvc.Logger()
+        """ This function will update the order status in OpenERP for
+        the order which are in the state 'need to update' """
         so_obj = self.pool.get('sale.order')
 
         for shop in self.browse(cr, uid, ids):
@@ -170,86 +169,21 @@
             # from the Magento's corresponding orders
     
             # Get all need_to_update orders in OERP
-            orders_to_update = so_obj.search(cr,uid,[('need_to_update', '=', True), ('shop_id', '=', shop.id)])
-            for order in so_obj.browse(cr, uid, orders_to_update):
-                mag_status = ORDER_STATUS_MAPPING.get(order.state, False)
-                # For each one, check if the status has change in Magento
-                # We dont use oeid_to_extid function cause it only handle int id
-                # Magento can have something like '100000077-2'
-                model_data_ids = self.pool.get('ir.model.data').search(cr, uid, [('model', '=', so_obj._name), ('res_id', '=', order.id), ('external_referential_id', '=', shop.referential_id.id)])
-                if model_data_ids:
-                    prefixed_id = self.pool.get('ir.model.data').read(cr, uid, model_data_ids[0], ['name'])['name']
-                    ext_id = so_obj.id_from_prefixed_id(prefixed_id)
-                else:
-                    return False
-                data_record=conn.call('sales_order.info', [ext_id])
-                updated = False
-                if data_record['status'] == 'canceled':
-                    wf_service = netsvc.LocalService("workflow")
-                    wf_service.trg_validate(uid, 'sale.order', order.id, 'cancel', cr)
-                    updated = True
-                    self.log(cr, uid, order.id, "order %s canceled when updated from external system" % (order.id,))
-                    logger.notifyChannel('ext synchro', netsvc.LOG_INFO, "order %s canceled when updated from external system" % (order.id,))
-                # If the order isn't canceled and was blocked, 
-                # so we follow the standard flow according to ext_payment_method:
-                else:
-                    paid = so_obj.create_payments(cr, uid, order.id, data_record, context)                        
-                    so_obj.oe_status(cr, uid, order.id, paid, context)
-                    updated = paid
-                    if paid:
-                        self.log(cr, uid, order.id, "order %s paid when updated from external system" % (order.id,))
-                        logger.notifyChannel('ext synchro', netsvc.LOG_INFO, "order %s paid when updated from external system" % (order.id,))
-                # Untick the need_to_update if updated (if so was canceled in magento
-                # or if it has been paid through magento)
-                if updated:
-                    so_obj.write(cr, uid, order.id, {'need_to_update': False})
-                cr.commit();
+            orders_to_update = so_obj.search(
+                cr, uid,
+                [('need_to_update', '=', True),
+                 ('shop_id', '=', shop.id)],
+                context=context)
+            so_obj.check_need_to_update(
+                cr, uid, orders_to_update, conn, context=context)
         return False
 
-    def _create_magento_invoice(self, cr, uid, order, conn, ext_id, context=None):
-        """ Creation of an invoice on Magento."""
-        cr.execute("select account_invoice.id "
-                   "from account_invoice "
-                   "inner join sale_order_invoice_rel "
-                   "on invoice_id = account_invoice.id "
-                   "where order_id = %s" % order.id)
-        resultset = cr.fetchone()
-        created = False
-        if resultset and len(resultset) == 1:
-            invoice = self.pool.get("account.invoice").browse(
-                cr, uid, resultset[0], context=context)
-            if (invoice.amount_total == order.amount_total and
-                not invoice.magento_ref):
-                try:
-                    magento_invoice_ref = conn.call(
-                        'sales_order_invoice.create',
-                        [order.magento_incrementid,
-                         [],
-                         _("Invoice Created"),
-                         True,
-                         order.shop_id.allow_magento_notification])
-                    self.pool.get("account.invoice").write(
-                        cr, uid,
-                        invoice.id,
-                        {'magento_ref': magento_invoice_ref,
-                         'origin': magento_invoice_ref})
-                    self.log(cr, uid, order.id,
-                             "created Magento invoice for order %s" %
-                             (order.id,))
-                    created = True
-                except Exception, e:
-                    self.log(cr, uid, order.id,
-                             "failed to create Magento invoice for order %s" %
-                             (order.id,))
-                    # TODO make sure that's because Magento invoice already
-                    # exists and then re-attach it!
-        return created
-
     def update_shop_orders(self, cr, uid, order, ext_id, context=None):
         if context is None: context = {}
         result = {}
 
         if order.shop_id.allow_magento_order_status_push:
+            sale_obj = self.pool.get('sale.order')
             #status update:
             conn = context.get('conn_obj', False)
             status = ORDER_STATUS_MAPPING.get(order.state, False)
@@ -262,10 +196,10 @@
                 # then we consider the update is done
                 # remove the 'need_to_update': True
                 if order.need_to_update:
-                    self.pool.get('sale.order').write(
+                    sale_obj.write(
                         cr, uid, order.id, {'need_to_update': False})
 
-            self._create_magento_invoice(
+            sale_obj.export_invoice(
                 cr, uid, order, conn, ext_id, context=context)
         return result
 
@@ -279,8 +213,8 @@
         if ids:
             callback(cr, uid, ids, context=context)
 
-        tools.debug(callback)
-        tools.debug(ids)
+        # tools.debug(callback)
+        # tools.debug(ids)
         return True
 
     # Schedules functions ============ #
@@ -309,8 +243,12 @@
     _inherit = "sale.order"
     
     _columns = {
-                'magento_incrementid': fields.char('Magento Increment ID', size=32),
-                'magento_storeview_id': fields.many2one('magerp.storeviews', 'Magento Store View'),
+        'magento_incrementid': fields.char('Magento Increment ID', size=32),
+        'magento_storeview_id': fields.many2one('magerp.storeviews', 'Magento Store View'),
+        'is_magento': fields.related(
+            'shop_id', 'referential_id', 'magento_referential',
+            type='boolean',
+            string='Is a Magento Sale Order')
     }
     
     def _auto_init(self, cr, context=None):
@@ -321,7 +259,10 @@
         super(sale_order, self)._auto_init(cr, context)
         
     def get_mage_customer_address_id(self, address_data):
-        if address_data.get('customer_address_id', False):
+        # sometimes magento put nothing or '0' for the id, in such case
+        # we have to create an new address
+        if address_data.get('customer_address_id') and \
+           address_data['customer_address_id'] != '0':
             return {'customer_address_id': address_data['customer_address_id'], 'is_magento_order_address': False}
         else:
             return {'customer_address_id': 'mag_order' + str(address_data['address_id']), 'is_magento_order_address': True}
@@ -340,23 +281,40 @@
         if 'address_type' in data_record['shipping_address']:
             data_record['shipping_address'].update(self.get_mage_customer_address_id(data_record['shipping_address']))
         shipping_default = {}
-        billing_default = {}
-        res['partner_id'] = self.pool.get('res.partner').extid_to_oeid(cr, uid, data_record['customer_id'], external_referential_id)
+
+        if res is None:
+            res = {}
+
+        # always update the customer when importing an order
+        partner_obj.get_external_data(
+            cr, uid,
+            context.get('conn_obj'),
+            external_referential_id,
+            defaults={},
+            context={'id': data_record['customer_id']})
+        res['partner_id'] = partner_obj.extid_to_oeid(cr, uid, data_record['customer_id'], external_referential_id)
+
         if res.get('partner_id', False):
             shipping_default = {'partner_id': res.get('partner_id', False)}
         billing_default = shipping_default.copy()
         billing_default.update({'email' : data_record.get('customer_email', False)})
 
-        inv_res = partner_address_obj.ext_import(cr, uid, [data_record['billing_address']], external_referential_id, billing_default, context)
-        if 'address_type' in data_record['shipping_address']:
-            ship_res = partner_address_obj.ext_import(cr, uid, [data_record['shipping_address']], external_referential_id, shipping_default, context)
-        else:
-            ship_res = partner_address_obj.ext_import(cr, uid, [data_record['billing_address']], external_referential_id, shipping_default, context)
-
-        res['partner_order_id'] = len(inv_res['create_ids']) > 0 and inv_res['create_ids'][0] or inv_res['write_ids'][0]
+        inv_res = partner_address_obj.ext_import(
+            cr, uid, [data_record['billing_address']], external_referential_id, billing_default, context)
+        res['partner_order_id'] = inv_res.get('create_ids') and inv_res['create_ids'][0] or inv_res['write_ids'][0]
         res['partner_invoice_id'] = res['partner_order_id']
-        res['partner_shipping_id'] = (len(ship_res['create_ids']) > 0 and ship_res['create_ids'][0]) or (len(ship_res['write_ids']) > 0 and ship_res['write_ids'][0]) or res['partner_order_id'] #shipping might be the same as invoice address
-        
+
+        if data_record['shipping_address']:
+            ship_res = partner_address_obj.ext_import(
+                cr, uid, [data_record['shipping_address']], external_referential_id, shipping_default, context)
+            res['partner_shipping_id'] = (ship_res.get('create_ids') and ship_res['create_ids'][0]) or \
+                                         (ship_res.get('write_ids') and ship_res['write_ids'][0]) \
+                                         or False
+
+        # when there is no shipping address, use the order's one
+        if not res.get('partner_shipping_id'):
+            res['partner_shipping_id'] = res['partner_order_id']
+
         result = partner_address_obj.read(cr, uid, res['partner_order_id'], ['partner_id'])
         if result and result['partner_id']:
             partner_id = result['partner_id'][0]
@@ -410,37 +368,6 @@
             partner_obj.write(cr, uid, [partner_id], partner_vals)
         return res
     
-    def get_order_lines(self, cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context=None):
-        if context is None: context = {}
-        mapping_id = self.pool.get('external.mapping').search(cr,uid,[('model','=','sale.order.line'),('referential_id','=',external_referential_id)])
-        if mapping_id:
-            mapping_line_ids = self.pool.get('external.mapping.line').search(cr,uid,[('mapping_id','=',mapping_id[0]),('type','in',['in_out','in'])])
-            mapping_lines = self.pool.get('external.mapping.line').read(cr,uid,mapping_line_ids,['external_field','external_type','in_function'])
-            if mapping_lines:
-                lines_vals = []
-                is_tax_included = defaults.get('price_type', False) == 'tax_included'
-                for line_data in data_record.get('items', []):
-                    # Setting the UoM in sale order line as defined in product definition in openerp
-                    product_id = self.pool.get('product.product').extid_to_oeid(cr, uid, line_data['product_id'], external_referential_id)
-                    product = self.pool.get('product.product').browse(cr, uid, product_id)
-                    defaults_line = {'product_uom': product.uom_id.id}
-                    #simple VAT tax on order line (else override method):
-                    line_tax_vat = float(line_data.get('tax_percent', False) or 0) / 100.0
-                    if line_tax_vat > 0:
-                        line_tax_ids = self.pool.get('account.tax').search(cr, uid, ['|', ('type_tax_use', '=', 'all'), ('type_tax_use', '=', 'sale'), ('price_include', '=', is_tax_included), ('amount', '>=', line_tax_vat - 0.001), ('amount', '<=', line_tax_vat + 0.001)])
-                        if line_tax_ids and len(line_tax_ids) > 0:
-                            defaults_line['tax_id'] = [(6, 0, [line_tax_ids[0]])]
-                    context.update({'partner_id': res['partner_id'], 'pricelist_id': res['pricelist_id']})
-                    if defaults.get('price_type', False) == 'tax_included':
-                        context.update({'price_is_tax_included': True})
-                    line_val = self.oevals_from_extdata(cr, uid, external_referential_id, line_data, 'item_id', mapping_lines, defaults_line, context)
-                    if line_val['product_id']:
-                        line_val['type'] = self.pool.get('product.product').read(cr, uid, line_val['product_id'], ['procure_method'], context)['procure_method']
-                    if not line_val.has_key('_CANCEL_IMPORT'):
-                        lines_vals.append((0, 0, line_val))
-                res['order_line'] = lines_vals
-        return res
-
 
     def add_order_extra_line(self, cr, uid, res, data_record, ext_field, product_ref, defaults, context=None):
         """ Add or substract amount on order as a separate line item with single quantity for each type of amounts like :
@@ -464,21 +391,8 @@
 
         model, product_id = model_data_obj.get_object_reference(cr, uid, *product_ref)
         product = self.pool.get('product.product').browse(cr, uid, product_id, context)
-        is_tax_included = defaults.get('price_type', False) == 'tax_included'
+        is_tax_included = context.get('price_is_tax_included', False)
         amount = float(data_record[ext_field]) * sign
-        tax_id = []
-        if ext_tax_field:
-            if data_record[ext_tax_field] and float(data_record[ext_tax_field]) != 0:
-                tax_vat = abs(float(data_record[ext_tax_field]) / amount)
-                tax_ids = self.pool.get('account.tax').search(cr, uid, [('price_include', '=', is_tax_included), ('type_tax_use', '=', 'sale'), ('amount', '>=', tax_vat - 0.001), ('amount', '<=', tax_vat + 0.001)])
-                if tax_ids and len(tax_ids) > 0:
-                    tax_id = [(6, 0, [tax_ids[0]])]
-                else:
-                    #try to find a tax with less precision 
-                    tax_ids = self.pool.get('account.tax').search(cr, uid, [('price_include', '=', is_tax_included), ('type_tax_use', '=', 'sale'), ('amount', '>=', tax_vat - 0.01), ('amount', '<=', tax_vat + 0.01)])
-                if tax_ids and len(tax_ids) > 0:
-                    tax_id = [(6, 0, [tax_ids[0]])]
-
         name = product.name
         if ext_code_field and data_record.get(ext_code_field, False):
             name = "%s [%s]" % (name, data_record[ext_code_field])
@@ -488,17 +402,30 @@
         else:
             price_unit = float(amount)
 
-        res['order_line'].append((0, 0, {
-                                    'product_id': product.id,
-                                    'name': name,
-                                    'product_uom': product.uom_id.id,
-                                    'product_uom_qty': 1,
-                                    'price_unit': price_unit,
-                                    'tax_id': tax_id
-                                }))
+        extra_line = {
+                        'product_id': product.id,
+                        'name': name,
+                        'product_uom': product.uom_id.id,
+                        'product_uom_qty': 1,
+                        'price_unit': price_unit,
+                    }
+
+        if not res.get('order_line'):
+            res['order_line'] = []
+
+        if context.get('use_external_tax'):
+            # get the tax computed by the external system
+            tax_vat = abs(float(data_record[ext_tax_field]) / amount)
+            line_tax_id = self.pool.get('account.tax').get_tax_from_rate(cr, uid, tax_vat, context.get('is_tax_included'), context=context)
+            extra_line['tax_id'] = [(6, 0, line_tax_id)]
+        else:
+            # compute the taxes, apply fiscal positions, default values and so on
+            extra_line = self.pool.get('sale.order.line').play_sale_order_line_onchange(cr, uid, extra_line, res, res['order_line'], defaults, context=context)
+        res['order_line'].append((0, 0, extra_line))
+
         return res
     
-    def add_order_shipping(self, cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context=None):
+    def add_order_shipping(self, cr, uid, res, external_referential_id, data_record, defaults, context=None):
         if context is None: context = {}
         if data_record.get('shipping_amount', False) and float(data_record.get('shipping_amount', False)) > 0:
             ctx = context.copy()
@@ -509,7 +436,7 @@
             res = self.add_order_extra_line(cr, uid, res, data_record, 'shipping_amount', product_ref, defaults, ctx)
         return res
 
-    def add_gift_certificates(self, cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context=None):
+    def add_gift_certificates(self, cr, uid, res, external_referential_id, data_record, defaults, context=None):
         if context is None: context = {}
         if data_record.get('giftcert_amount', False) and float(data_record.get('giftcert_amount', False)) > 0:
             ctx = context.copy()
@@ -521,7 +448,7 @@
             res = self.add_order_extra_line(cr, uid, res, data_record, 'giftcert_amount', product_ref, defaults, ctx)
         return res
 
-    def add_discount(self, cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context=None):
+    def add_discount(self, cr, uid, res, external_referential_id, data_record, defaults, context=None):
         #TODO fix me rev 476
         #if data_record.get('discount_amount', False) and float(data_record.get('discount_amount', False)) < 0:
         #    ctx = context.copy()
@@ -532,7 +459,7 @@
         #    res = self.add_order_extra_line(cr, uid, res, data_record, 'discount_amount', product_ref, defaults, ctx)
         return res
 
-    def add_cash_on_delivery(self, cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context=None):
+    def add_cash_on_delivery(self, cr, uid, res, external_referential_id, data_record, defaults, context=None):
         if context is None: context = {}
         if data_record.get('cod_fee', False) and float(data_record.get('cod_fee', False)) > 0:
             ctx = context.copy()
@@ -542,6 +469,16 @@
             product_ref = ('magentoerpconnect', 'product_product_cash_on_delivery')
             res = self.add_order_extra_line(cr, uid, res, data_record, 'cod_fee', product_ref, defaults, ctx)
         return res
+    
+    def convert_extdata_into_oedata(self, cr, uid, external_data, external_referential_id, parent_data=None, defaults=None, context=None):
+        res = super(sale_order, self).convert_extdata_into_oedata(cr, uid, external_data, external_referential_id, parent_data=parent_data, defaults=defaults, context=context)
+        res=res[0]
+        external_data = external_data[0]
+        res = self.add_order_shipping(cr, uid, res, external_referential_id, external_data, defaults, context)
+        res = self.add_gift_certificates(cr, uid, res, external_referential_id, external_data, defaults, context)
+        res = self.add_discount(cr, uid, res, external_referential_id, external_data, defaults, context)
+        res = self.add_cash_on_delivery(cr, uid, res, external_referential_id, external_data, defaults, context)
+        return [res]
 
     def _merge_sub_items(self, cr, uid, product_type, top_item, child_items, context=None):
         """
@@ -592,62 +529,69 @@
         
         data_record['items'] = all_items
         return data_record
-    
-    
-    def get_all_order_lines(self, cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context=None):
-        res = self.get_order_lines(cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context)
-        res = self.add_order_shipping(cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context)
-        res = self.add_gift_certificates(cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context)
-        res = self.add_discount(cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context)
-        res = self.add_cash_on_delivery(cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context)
-        return res
 
-    def oevals_from_extdata(self, cr, uid, external_referential_id, data_record, key_field, mapping_lines, defaults, context=None):
+    def oevals_from_extdata(self, cr, uid, external_referential_id, data_record, key_field, mapping_lines, parent_data=None, previous_lines=None, defaults=None, context=None):
         if context is None: context = {}
         if data_record.get('items', False):
             data_record = self.data_record_filter(cr, uid, data_record, context=context)
-        
+        #TODO refactor this code regarding the new feature of sub-mapping in base_external_referential
         if not context.get('one_by_one', False):
             if data_record.get('billing_address', False):
                 defaults = self.get_order_addresses(cr, uid, defaults, external_referential_id, data_record, key_field, mapping_lines, defaults, context)
-        
-        res = super(magerp_osv.magerp_osv, self).oevals_from_extdata(cr, uid, external_referential_id, data_record, key_field, mapping_lines, defaults, context)
+        res = super(magerp_osv.magerp_osv, self).oevals_from_extdata(cr, uid, external_referential_id, data_record, key_field, mapping_lines, parent_data, previous_lines, defaults, context)
 
-        if not context.get('one_by_one', False):
-            if data_record.get('items', False):
-                if NOTRY:
-                    res = self.get_all_order_lines(cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context)
-                else:
-                    #TODO fix me error should be raise correctly in the reporting system
-                    res = self.get_all_order_lines(cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context)
-                    #try:
-                    #    res = self.get_all_order_lines(cr, uid, res, external_referential_id, data_record, key_field, mapping_lines, defaults, context)
-                    #except Exception, e:
-                    #    print "order has errors with items lines, data are: ", data_record
-                    #    print e
-                        #TODO flag that the order has an error, especially.
-            
+        #Move me in a mapping
+        if not context.get('one_by_one', False):            
             if data_record.get('status_history', False) and len(data_record['status_history']) > 0:
                 res['date_order'] = data_record['status_history'][len(data_record['status_history'])-1]['created_at']
         return res
-    
+
+    def _parse_external_payment(self, cr, uid, order_data, context=None):
+        """
+        Parse the external order data and return if the sale order
+        has been paid and the amount to pay or to be paid
+
+        :param dict order_data: payment information of the magento sale
+            order
+        :return: tuple where :
+            - first item indicates if the payment has been done (True or False)
+            - second item represents the amount paid or to be paid
+        """
+        paid = amount = False
+        payment_info = order_data.get('payment')
+        if payment_info:
+            amount = False
+            if payment_info.get('amount_paid', False):
+                amount =  payment_info.get('amount_paid', False)
+                paid = True
+            elif payment_info.get('amount_ordered', False):
+                amount = payment_info.get('amount_ordered', False)
+        return paid, amount
+
     def create_payments(self, cr, uid, order_id, data_record, context=None):
-        if context is None: context = {}
-        if context.get('external_referential_type', False) and 'Magento' in context['external_referential_type']:
-            paid = False
-            if data_record.get('payment', False):
-                payment = data_record['payment']
-                amount = False
-                if payment.get('amount_paid', False):
-                    amount =  payment.get('amount_paid', False)
-                    paid = True
-                elif payment.get('amount_ordered', False):
-                    amount =  payment.get('amount_ordered', False)
-                if amount:
-                    order = self.pool.get('sale.order').browse(cr, uid, order_id, context)
-                    self.generate_payment_with_pay_code(cr, uid, payment['method'], order.partner_id.id, float(amount), "mag_" + payment['payment_id'], "mag_" + data_record['increment_id'], order.date_order, paid, context)
+        if context is None:
+            context = {}
+
+        if 'Magento' in context.get('external_referential_type', ''):
+            payment_info = data_record.get('payment')
+            paid, amount = self._parse_external_payment(
+                cr, uid, data_record, context=context)
+            if amount:
+                order = self.pool.get('sale.order').browse(
+                    cr, uid, order_id, context)
+                self.generate_payment_with_pay_code(
+                    cr, uid,
+                    payment_info['method'],
+                    order.partner_id.id,
+                    float(amount),
+                    "mag_" + payment_info['payment_id'],
+                    "mag_" + data_record['increment_id'],
+                    order.date_order,
+                    paid,
+                    context=context)
         else:
-            paid = super(sale_order, self).create_payments(cr, uid, order_id, data_record, context=context)
+            paid = super(sale_order, self).create_payments(
+                cr, uid, order_id, data_record, context=context)
         return paid
 
     def _chain_cancel_orders(self, cr, uid, external_id, external_referential_id, defaults=None, context=None):
@@ -772,21 +716,118 @@
             result['unchanged_ids'] = unchanged_ids
         return result
 
-# UPDATE ORDER STATUS FROM MAGENTO TO OPENERP IS UNSTABLE, AND NOT VERY USEFULL. MAYBE IT WILL BE REFACTORED 
-
-    #def oe_update(self,cr, uid, existing_rec_id, vals, data, external_referential_id, defaults, context):
-        #order_line_ids = self.pool.get('sale.order.line').search(cr,uid,[('order_id','=', existing_rec_id)])
-        #self.pool.get('sale.order.line').unlink(cr, uid, order_line_ids)
-        #TODO update order status eventually (that would be easier if they were linked by some foreign key...)
-        #self.oe_status(cr, uid, data, existing_rec_id, context)
-        #return super(magerp_osv.magerp_osv, self).oe_update(cr, uid, existing_rec_id, vals, data, external_referential_id, defaults, context)
-
-    #def oe_status(self, cr, uid, data, order_id, context):
-        #wf_service = netsvc.LocalService("workflow")
-        #if data.get('status_history', False) and len(data['status_history']) > 0 and data['status_history'][0]['status'] == 'canceled':
-        #   wf_service.trg_validate(uid, 'sale.order', order_id, 'cancel', cr)
-        #else:
-        #   super(magerp_osv.magerp_osv, self).oe_status(cr, uid, order_id, context)
-    
+    def _check_need_to_update_single(self, cr, uid, order, conn, context=None):
+        """
+        For one order, check on Magento if it has been paid since last
+        check. If so, it will launch the defined flow based on the
+        payment type (validate order, invoice, ...)
+
+        :param browse_record order: browseable sale.order
+        :param Connection conn: connection with Magento
+        :return: True
+        """
+        model_data_obj = self.pool.get('ir.model.data')
+        # check if the status has changed in Magento
+        # We don't use oeid_to_extid function cause it only handles integer ids
+        # Magento can have something like '100000077-2'
+        model_data_ids = model_data_obj.search(
+            cr, uid,
+            [('model', '=', self._name),
+             ('res_id', '=', order.id),
+             ('external_referential_id', '=', order.shop_id.referential_id.id)],
+            context=context)
+
+        if model_data_ids:
+            prefixed_id = model_data_obj.read(
+                cr, uid, model_data_ids[0], ['name'], context=context)['name']
+            ext_id = self.id_from_prefixed_id(prefixed_id)
+        else:
+            return False
+
+        data_record = conn.call('sales_order.info', [ext_id])
+
+        if data_record['status'] == 'canceled':
+            wf_service = netsvc.LocalService("workflow")
+            wf_service.trg_validate(uid, 'sale.order', order.id, 'cancel', cr)
+            updated = True
+            self.log(cr, uid, order.id, "order %s canceled when updated from external system" % (order.id,))
+        # If the order isn't canceled and was waiting for a payment,
+        # so we follow the standard flow according to ext_payment_method:
+        else:
+            paid, __ = self._parse_external_payment(
+                cr, uid, data_record, context=context)
+            self.oe_status(cr, uid, order.id, paid, context)
+            # create_payments has to be done after oe_status
+            # because oe_status creates the invoice
+            # and create_payment could reconcile the payment
+            # with the invoice
+
+            updated = self.create_payments(
+                cr, uid, order.id, data_record, context)
+            if updated:
+                self.log(
+                    cr, uid, order.id,
+                    "order %s paid when updated from external system" %
+                    (order.id,))
+        # Untick the need_to_update if updated (if so was canceled in magento
+        # or if it has been paid through magento)
+        if updated:
+            self.write(cr, uid, order.id, {'need_to_update': False})
+        cr.commit()
+        return True
+
+    def check_need_to_update(self, cr, uid, ids, conn, context=None):
+        """
+        For each order, check on Magento if it has been paid since last
+        check. If so, it will launch the defined flow based on the
+        payment type (validate order, invoice, ...)
+
+        :param Connection conn: connection with Magento
+        :return: True
+        """
+        for order in self.browse(cr, uid, ids, context=context):
+            self._check_need_to_update_single(
+                cr, uid, order, conn, context=context)
+        return True
+
+    def _create_external_invoice(self, cr, uid, order, conn, ext_id,
+                                context=None):
+        """ Creation of an invoice on Magento."""
+        magento_invoice_ref = conn.call(
+            'sales_order_invoice.create',
+            [order.magento_incrementid,
+            [],
+             _("Invoice Created"),
+             True,
+             order.shop_id.allow_magento_notification])
+        return magento_invoice_ref
+
+    # TODO Move in base_sale_multichannels?
+    def export_invoice(self, cr, uid, order, conn, ext_id, context=None):
+        """ Export an invoice on external referential """
+        cr.execute("select account_invoice.id "
+                   "from account_invoice "
+                   "inner join sale_order_invoice_rel "
+                   "on invoice_id = account_invoice.id "
+                   "where order_id = %s" % order.id)
+        resultset = cr.fetchone()
+        created = False
+        if resultset and len(resultset) == 1:
+            invoice = self.pool.get("account.invoice").browse(
+                cr, uid, resultset[0], context=context)
+            if (invoice.amount_total == order.amount_total and
+                not invoice.magento_ref):
+                try:
+                    self._create_external_invoice(
+                        cr, uid, order, conn, ext_id, context=context)
+                    created = True
+                except Exception, e:
+                    self.log(cr, uid, order.id,
+                             "failed to create Magento invoice for order %s" %
+                             (order.id,))
+                    # TODO make sure that's because Magento invoice already
+                    # exists and then re-attach it!
+        return created
+
 sale_order()
 

=== modified file 'magentoerpconnect/sale_view.xml'
--- magentoerpconnect/sale_view.xml	2011-11-17 17:54:05 +0000
+++ magentoerpconnect/sale_view.xml	2012-03-27 09:40:33 +0000
@@ -67,5 +67,24 @@
 			</field>
 		</record>
 
+        <record id="base_sale_multichannel_view_order_form_magento" model="ir.ui.view">
+            <field name="name">base_sale_multichannel_view_order_form.magento</field>
+            <field name="model">sale.order</field>
+            <field name="inherit_id" ref="base_sale_multichannels.base_sale_multichannel_view_order_form"/>
+            <field name="type">form</field>
+            <field name="arch" type="xml">
+                <data>
+                    <page string="External Information" position="inside">
+                        <group colspan="4" attrs="{'invisible': [('is_magento', '=', False)]}">
+                            <field name="is_magento" invisible="True"/>
+                            <separator string="Magento History" colspan="4"/>
+                            <field name="magento_incrementid" readonly="True"/>
+                            <field name="magento_storeview_id" readonly="True"/>
+                        </group>
+                    </page>
+                </data>
+            </field>
+        </record>
+        
 	</data>
 </openerp>

=== modified file 'magentoerpconnect/security/ir.model.access.csv'
--- magentoerpconnect/security/ir.model.access.csv	2011-11-18 10:19:26 +0000
+++ magentoerpconnect/security/ir.model.access.csv	2012-03-08 00:43:50 +0000
@@ -1,15 +1,15 @@
-"id","name","model_id:id","group_id:id","perm_read","perm_write","perm_create","perm_unlink"
-"access_magentoerpconnect_magerp_product_category_attribute_options","magerp_product_category_attribute_options","model_magerp_product_category_attribute_options","base.group_sale_manager",1,0,0,0
-"access_magentoerpconnect_magerp_product_attributes","magerp_product_attributes","model_magerp_product_attributes","base.group_sale_manager",1,0,0,0
-"access_magentoerpconnect_magerp_product_attribute_set","magerp_product_attribute_set","model_magerp_product_attribute_set","base.group_sale_manager",1,0,0,0
-"access_magentoerpconnect_magerp_product_attribute_groups","magerp_product_attribute_groups","model_magerp_product_attribute_groups","base.group_sale_manager",1,0,0,0
-"access_magentoerpconnect_magerp_product_attribute_options","magerp_product_attribute_options","model_magerp_product_attribute_options","base.group_sale_manager",1,0,0,0
-"access_magentoerpconnect_product_tierprice","product_tierprice","model_product_tierprice","base.group_sale_manager",1,1,1,1
-"access_magentoerpconnect_model_magerp_product_product_type","model_magerp_product_product_type","model_magerp_product_product_type","base.group_sale_manager",1,0,0,0
-"access_magentoerpconnect_magerp_storeviews","magerp_storeviews","model_magerp_storeviews","base.group_sale_manager",1,1,1,1
-"access_magentoerpconnect_magerp_product_attributes_manager","magerp_product_attributes","model_magerp_product_attributes","stock.group_stock_manager",1,1,1,1
-"access_magentoerpconnect_magerp_product_category_attribute_options_manager","magerp_product_category_attribute_options","model_magerp_product_category_attribute_options","stock.group_stock_manager",1,1,1,1
-"access_magentoerpconnect_magerp_product_attribute_set_manager","magerp_product_attribute_set","model_magerp_product_attribute_set","stock.group_stock_manager",1,1,1,1
-"access_magentoerpconnect_magerp_product_attribute_groups_manager","magerp_product_attribute_groups","model_magerp_product_attribute_groups","stock.group_stock_manager",1,1,1,1
-"access_magentoerpconnect_magerp_product_attribute_options_manager","magerp_product_attribute_options","model_magerp_product_attribute_options","stock.group_stock_manager",1,1,1,1
-"access_magentoerpconnect_model_magerp_product_product_type_manager","model_magerp_product_product_type","model_magerp_product_product_type","stock.group_stock_manager",1,1,1,1
+id,name,model_id:id,group_id:id,perm_read,perm_write,perm_create,perm_unlink
+access_magentoerpconnect_magerp_product_category_attribute_options,magerp_product_category_attribute_options,model_magerp_product_category_attribute_options,base.group_user,1,0,0,0
+access_magentoerpconnect_magerp_product_attributes,magerp_product_attributes,model_magerp_product_attributes,base.group_user,1,0,0,0
+access_magentoerpconnect_magerp_product_attribute_set,magerp_product_attribute_set,model_magerp_product_attribute_set,base.group_user,1,0,0,0
+access_magentoerpconnect_magerp_product_attribute_groups,magerp_product_attribute_groups,model_magerp_product_attribute_groups,base.group_user,1,0,0,0
+access_magentoerpconnect_magerp_product_attribute_options,magerp_product_attribute_options,model_magerp_product_attribute_options,base.group_user,1,0,0,0
+access_magentoerpconnect_model_magerp_product_product_type,model_magerp_product_product_type,model_magerp_product_product_type,base.group_user,1,0,0,0
+access_magentoerpconnect_product_tierprice,product_tierprice,model_product_tierprice,base.group_sale_manager,1,1,1,1
+access_magentoerpconnect_magerp_storeviews,magerp_storeviews,model_magerp_storeviews,base.group_sale_manager,1,1,1,1
+access_magentoerpconnect_magerp_product_attributes_manager,magerp_product_attributes,model_magerp_product_attributes,stock.group_stock_manager,1,1,1,1
+access_magentoerpconnect_magerp_product_category_attribute_options_manager,magerp_product_category_attribute_options,model_magerp_product_category_attribute_options,stock.group_stock_manager,1,1,1,1
+access_magentoerpconnect_magerp_product_attribute_set_manager,magerp_product_attribute_set,model_magerp_product_attribute_set,stock.group_stock_manager,1,1,1,1
+access_magentoerpconnect_magerp_product_attribute_groups_manager,magerp_product_attribute_groups,model_magerp_product_attribute_groups,stock.group_stock_manager,1,1,1,1
+access_magentoerpconnect_magerp_product_attribute_options_manager,magerp_product_attribute_options,model_magerp_product_attribute_options,stock.group_stock_manager,1,1,1,1
+access_magentoerpconnect_model_magerp_product_product_type_manager,model_magerp_product_product_type,model_magerp_product_product_type,stock.group_stock_manager,1,1,1,1

=== modified file 'magentoerpconnect/settings/1.3.2.4/external.mapping.template.csv'
--- magentoerpconnect/settings/1.3.2.4/external.mapping.template.csv	2011-11-27 19:01:32 +0000
+++ magentoerpconnect/settings/1.3.2.4/external.mapping.template.csv	2012-03-27 09:40:33 +0000
@@ -7,7 +7,7 @@
 "magento_1324_pro_cat","magento1324","product.model_product_category","category.list","category.info","catalog_category.update","catalog_category.create",,"category_id"
 "magento_1324_attr_grp","magento1324","model_magerp_product_attribute_groups","ol_catalog_product_attribute_group.list","ol_catalog_product_attribute_group.list",,,,"attribute_group_id"
 "magento_1324_attr_set","magento1324","model_magerp_product_attribute_set","ol_catalog_product_attributeset.list",,,,,"attribute_set_id"
-"magento_1324_attr","magento1324","model_magerp_product_attributes","ol_catalog_product_attribute.list",,,,,"magento_id"
+"magento_1324_attr","magento1324","model_magerp_product_attributes","ol_catalog_product_attribute.list",,,,,"attribute_id"
 "magento_1324_prd","magento1324","product.model_product_product","catalog_product.list","catalog_product.info","ol_catalog_product.update","ol_catalog_product.create",,"product_id"
 "magento_1324_cst_grp","magento1324","base.model_res_partner_category","ol_customer_groups.list",,,,,"customer_group_id"
 "magento_1324_prt_adr","magento1324","base.model_res_partner_address","ol_customer_address.list","ol_customer_address.info",,,,"customer_address_id"

=== modified file 'magentoerpconnect/settings/1.3.2.4/external.mappinglines.template.csv'
--- magentoerpconnect/settings/1.3.2.4/external.mappinglines.template.csv	2011-12-30 07:48:40 +0000
+++ magentoerpconnect/settings/1.3.2.4/external.mappinglines.template.csv	2012-03-27 09:40:33 +0000
@@ -1,24 +1,24 @@
-"id","type_id:id","model_id:id","external_field","type","external_type","in_function","out_function"
-"mag_1324_erp_s_name","magento1324","base_sale_multichannels.model_external_shop_group","name","in_out","unicode","result=[('name',ifield)]","result=[('name',record['name'])]"
-"mag_1324_erp_s_code","magento1324","base_sale_multichannels.model_external_shop_group","code","in_out","unicode","result=[('code',ifield)]",
-"mag_1324_erp_s_web","magento1324","base_sale_multichannels.model_external_shop_group","website_id","in_out","int","result=[('website_id',ifield)]",
-"mag_1324_erp_s_isa","magento1324","base_sale_multichannels.model_external_shop_group","is_default","in_out","unicode","result=[('is_default',bool(eval(ifield)))]",
-"mag_1324_erp_s_stord","magento1324","base_sale_multichannels.model_external_shop_group","sort_order","in_out","int","result=[('sort_order',ifield)]",
-"mag_1324_erp_s_gpid","magento1324","base_sale_multichannels.model_external_shop_group","default_group_id","in_out","int","result=[('default_shop_integer_id',ifield)]",
-"mag_1324_erp_sv_name","magento1324","model_magerp_storeviews","name","in_out","unicode","result=[('name',ifield)]","result=[('name',record['name'])]"
-"mag_1324_erp_sv_code","magento1324","model_magerp_storeviews","code","in_out","unicode","result=[('code',ifield)]",
-"mag_1324_erp_sv_sg","magento1324","model_magerp_storeviews","website_id","in_out","int","result=[('website_id',self.pool.get('external.shop.group').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
-"mag_1324_erp_sv_isa","magento1324","model_magerp_storeviews","is_active","in_out","unicode","result=[('is_active',bool(eval(ifield)))]",
-"mag_1324_erp_sv_stord","magento1324","model_magerp_storeviews","sort_order","in_out","int","result=[('sort_order',ifield)]",
-"mag_1324_erp_sv_gpid","magento1324","model_magerp_storeviews","group_id","in_out","int","result=[('shop_id',self.pool.get('sale.shop').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
-"mag_1324_erp_st_name","magento1324","sale.model_sale_shop","name","in_out","unicode","result=[('name',ifield)]","result=[('name',record['name'])]"
-"mag_1324_erp_st_gpid","magento1324","sale.model_sale_shop","group_id","in_out","int","result=[('group_id',ifield)]",
-"mag_1324_erp_st_grp","magento1324","sale.model_sale_shop","website_id","in_out","int","result=[('shop_group_id',self.pool.get('external.shop.group').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
-"mag_1324_erp_st_default_st","magento1324","sale.model_sale_shop","default_store_id","in_out","int","result=[('default_storeview_integer_id',ifield)]",
-"mag_1324_erp_st_root_categ","magento1324","sale.model_sale_shop","root_category_id","in_out","int","result=[('root_category_id',ifield)]",
-"mag_1324_erp_so_total_amount","magento1324","sale.model_sale_order","grand_total","in_out","float","result=[('ext_total_amount',str(ifield))]",
-"mag_1324_erp_so_name","magento1324","sale.model_sale_order","increment_id","in_out","unicode","result=[('magento_incrementid',str(ifield)), ('name','mag_' + str(ifield))]",
-"mag_1324_erp_so_carrier_id","magento1324","sale.model_sale_order","shipping_method","in_out","unicode","if ifield:
+id,type_id:id,model_id:id,external_field,field_id:id,type,evaluation_type,external_type,child_mapping_id:id,in_function,out_function
+mag_1324_erp_s_name,magento1324,base_sale_multichannels.model_external_shop_group,name,,in_out,function,unicode,,"result=[('name',ifield)]","result=[('name',record['name'])]"
+mag_1324_erp_s_code,magento1324,base_sale_multichannels.model_external_shop_group,code,,in_out,function,unicode,,"result=[('code',ifield)]",
+mag_1324_erp_s_web,magento1324,base_sale_multichannels.model_external_shop_group,website_id,,in_out,function,int,,"result=[('website_id',ifield)]",
+mag_1324_erp_s_isa,magento1324,base_sale_multichannels.model_external_shop_group,is_default,,in_out,function,unicode,,"result=[('is_default',bool(eval(ifield)))]",
+mag_1324_erp_s_stord,magento1324,base_sale_multichannels.model_external_shop_group,sort_order,,in_out,function,int,,"result=[('sort_order',ifield)]",
+mag_1324_erp_s_gpid,magento1324,base_sale_multichannels.model_external_shop_group,default_group_id,,in_out,function,int,,"result=[('default_shop_integer_id',ifield)]",
+mag_1324_erp_sv_name,magento1324,model_magerp_storeviews,name,,in_out,function,unicode,,"result=[('name',ifield)]","result=[('name',record['name'])]"
+mag_1324_erp_sv_code,magento1324,model_magerp_storeviews,code,,in_out,function,unicode,,"result=[('code',ifield)]",
+mag_1324_erp_sv_sg,magento1324,model_magerp_storeviews,website_id,,in_out,function,int,,"result=[('website_id',self.pool.get('external.shop.group').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
+mag_1324_erp_sv_isa,magento1324,model_magerp_storeviews,is_active,,in_out,function,unicode,,"result=[('is_active',bool(eval(ifield)))]",
+mag_1324_erp_sv_stord,magento1324,model_magerp_storeviews,sort_order,,in_out,function,int,,"result=[('sort_order',ifield)]",
+mag_1324_erp_sv_gpid,magento1324,model_magerp_storeviews,group_id,,in_out,function,int,,"result=[('shop_id',self.pool.get('sale.shop').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
+mag_1324_erp_st_name,magento1324,sale.model_sale_shop,name,,in_out,function,unicode,,"result=[('name',ifield)]","result=[('name',record['name'])]"
+mag_1324_erp_st_gpid,magento1324,sale.model_sale_shop,group_id,,in_out,function,int,,"result=[('group_id',ifield)]",
+mag_1324_erp_st_grp,magento1324,sale.model_sale_shop,website_id,,in_out,function,int,,"result=[('shop_group_id',self.pool.get('external.shop.group').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
+mag_1324_erp_st_default_st,magento1324,sale.model_sale_shop,default_store_id,,in_out,function,int,,"result=[('default_storeview_integer_id',ifield)]",
+mag_1324_erp_st_root_categ,magento1324,sale.model_sale_shop,root_category_id,,in_out,function,int,,"result=[('root_category_id',ifield)]",
+mag_1324_erp_so_total_amount,magento1324,sale.model_sale_order,grand_total,,in_out,function,float,,"result=[('ext_total_amount',str(ifield))]",
+mag_1324_erp_so_name,magento1324,sale.model_sale_order,increment_id,,in_out,function,unicode,,"result=[('magento_incrementid',str(ifield)), ('name','mag_' + str(ifield))]",
+mag_1324_erp_so_carrier_id,magento1324,sale.model_sale_order,shipping_method,,in_out,function,unicode,,"if ifield:
     carrier_ids = self.pool.get('delivery.carrier').search(cr, uid, [('magento_code', '=', ifield)])
     if carrier_ids:
         result=[('carrier_id', carrier_ids[0])]
@@ -28,13 +28,14 @@
         model, product_id = model_data_obj.get_object_reference(cr, uid, 'base_sale_multichannels', 'product_product_shipping')
         carrier_id = self.pool.get('delivery.carrier').create(cr, uid, {'partner_id' : fake_partner_id, 'product_id' : product_id, 'name' : ifield, 'magento_code' : ifield})
         result=[('carrier_id', carrier_id)]",
-"mag_1324_erp_so_pay","magento1324","sale.model_sale_order","payment","in_out","unicode","
+mag_1324_erp_so_pay,magento1324,sale.model_sale_order,payment,,in_out,function,unicode,,"
 payments_mapping = {'checkmo': 'manual', 'ccsave': 'prepaid', 'free':'prepaid','googlecheckout':'prepaid','paypayl_express':'prepaid', 'paybox_system': 'prepaid', 'paypal_standard': 'prepaid', 'cashondelivery': 'manual', 'servired_standard': 'prepaid', 'bbva': 'prepaid', 'cofidis': 'prepaid'}
 ifield=eval(ifield)
 result=[('order_policy', ifield['method'] in payments_mapping and payments_mapping[ifield['method']] or 'prepaid'), ('ext_payment_method', ifield['method'])]",
-"mag_1324_erp_soline_name","magento1324","sale.model_sale_order_line","name","in_out","unicode","result=[('name', ifield)]
+mag_1324_erp_so_item,magento1324,sale.model_sale_order,items,sale.field_sale_order_order_line,in,sub-mapping,dict,magento_1324_order_line,,
+"mag_1324_erp_soline_name","magento1324","sale.model_sale_order_line","name",,"in_out","function","unicode",,"result=[('name', ifield)]
 ",
-"mag_1324_erp_soline_note","magento1324","sale.model_sale_order_line","product_options","in","unicode","if ifield:
+"mag_1324_erp_soline_note","magento1324","sale.model_sale_order_line","product_options",,"in","function","unicode",,"if ifield:
     import re
     options_label = []
     clean = re.sub('\w:\w:|\w:\w+;', '', ifield)
@@ -45,18 +46,18 @@
 	
     result=[('notes',  """".join(options_label).replace('""""', '\n').replace('""', ''))]
 ",
-"mag_1324_erp_soline_pid","magento1324","sale.model_sale_order_line","product_id","in_out","unicode","context['alternative_key'] = data['sku']
+mag_1324_erp_soline_pid,magento1324,sale.model_sale_order_line,product_id,,in_out,function,unicode,,"context['alternative_key'] = data['sku']
 result=[('product_id',self.pool.get('product.product').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
-"mag_1324_erp_soline_uomqty","magento1324","sale.model_sale_order_line","qty_ordered","in_out","unicode","result=[('product_uom_qty',ifield)]",
-"mag_1324_erp_soline_uosqty","magento1324","sale.model_sale_order_line","qty_ordered","in","unicode","result=[('product_uos_qty',ifield)]",
-"mag_1324_erp_soline_price","magento1324","sale.model_sale_order_line","price","in","unicode","if context.get('price_is_tax_included', False):             
+mag_1324_erp_soline_uomqty,magento1324,sale.model_sale_order_line,qty_ordered,,in_out,function,unicode,,"result=[('product_uom_qty',ifield)]",
+mag_1324_erp_soline_uosqty,magento1324,sale.model_sale_order_line,qty_ordered,,in,function,unicode,,"result=[('product_uos_qty',ifield)]",
+mag_1324_erp_soline_price,magento1324,sale.model_sale_order_line,price,,in,function,unicode,,"if context.get('price_is_tax_included', False):             
     result=[('price_unit', (float(data['row_total']) + float(data['tax_amount']))/float(data['qty_ordered']))]
 else:
     result=[('price_unit', float(data['row_total'])/float(data['qty_ordered']))]",
-"mag_1324_erp_soline_disc","magento1324","sale.model_sale_order_line","discount_amount","in","float","if ifield:
+mag_1324_erp_soline_disc,magento1324,sale.model_sale_order_line,discount_amount,,in,function,float,,"if ifield:
     result=[('discount', float(data['price']) != 0 and float(data['qty_ordered']) != 0 and float(100*ifield)/(float(data['price'])*float(data['qty_ordered'])) or 0)]",
-"mag_1324_erp_procat_2","magento1324","product.model_product_category","level","in","int","result=[('sequence',ifield),('level',ifield)]",
-"mag_1324_erp_procat_3","magento1324","product.model_product_category","parent_id","in_out","int","record_id = self.pool.get('ir.model.data').search(cr, uid, [('model', '=', self._name), ('name', '=', self.prefixed_id(ifield))])
+mag_1324_erp_procat_2,magento1324,product.model_product_category,level,,in,function,int,,"result=[('sequence',ifield),('level',ifield)]",
+mag_1324_erp_procat_3,magento1324,product.model_product_category,parent_id,,in_out,function,int,,"record_id = self.pool.get('ir.model.data').search(cr, uid, [('model', '=', self._name), ('name', '=', self.prefixed_id(ifield))])
 parent_id = False
 if record_id:
 	parent_rec = self.pool.get('ir.model.data').read(cr,uid,record_id[0],[])
@@ -69,16 +70,16 @@
 		magento_parent_id = self.oeid_to_extid(cr, uid, record.get('parent_id')[0], external_referential_id)
 if magento_parent_id:
 	result = [('parent_id',magento_parent_id)]"
-"mag_1324_erp_procat_4","magento1324","product.model_product_category","is_active","in_out","unicode","result=[('is_active',ifield and (eval(ifield)) or False)]","result=[('is_active',record['is_active'])]"
-"mag_1324_erp_procat_5","magento1324","product.model_product_category","description","in_out","unicode","result=[('description',ifield)]","result=[('description',record['description'])]"
-"mag_1324_erp_procat_6","magento1324","product.model_product_category","meta_title","in_out","unicode","result=[('meta_title',ifield)]","result=[('meta_title',record['meta_title'])]"
-"mag_1324_erp_procat_7","magento1324","product.model_product_category","meta_keywords","in_out","unicode","result=[('meta_keywords',ifield)]","result=[('meta_keywords',record['meta_keywords'])]"
-"mag_1324_erp_procat_8","magento1324","product.model_product_category","meta_description","in_out","unicode","result=[('meta_description',ifield)]","result=[('meta_description',record['meta_description'])]"
-"mag_1324_erp_procat_9","magento1324","product.model_product_category","url_key","in_out","unicode","result=[('url_key',ifield)]","if context.get('export_url', False) :
+mag_1324_erp_procat_4,magento1324,product.model_product_category,is_active,,in_out,function,unicode,,"result=[('is_active',ifield and (eval(ifield)) or False)]","result=[('is_active',record['is_active'])]"
+mag_1324_erp_procat_5,magento1324,product.model_product_category,description,,in_out,function,unicode,,"result=[('description',ifield)]","result=[('description',record['description'])]"
+mag_1324_erp_procat_6,magento1324,product.model_product_category,meta_title,,in_out,function,unicode,,"result=[('meta_title',ifield)]","result=[('meta_title',record['meta_title'])]"
+mag_1324_erp_procat_7,magento1324,product.model_product_category,meta_keywords,,in_out,function,unicode,,"result=[('meta_keywords',ifield)]","result=[('meta_keywords',record['meta_keywords'])]"
+mag_1324_erp_procat_8,magento1324,product.model_product_category,meta_description,,in_out,function,unicode,,"result=[('meta_description',ifield)]","result=[('meta_description',record['meta_description'])]"
+mag_1324_erp_procat_9,magento1324,product.model_product_category,url_key,,in_out,function,unicode,,"result=[('url_key',ifield)]","if context.get('export_url', False) :
     result=[('url_key',record['url_key'])]"
-"mag_1324_erp_procat_10","magento1324","product.model_product_category","name","in_out","unicode","result=[('name',ifield or 'UNDEFINED'),('magento_exportable',True)]","result=[('name',record['name'])]"
-"mag_1324_erp_procat_11","magento1324","product.model_product_category","is_anchor","in_out","unicode","result=[('is_anchor',ifield and bool(eval(ifield)) or False)]","result=[('is_anchor',record['is_anchor'])]"
-"mag_1324_erp_procat_12","magento1324","product.model_product_category","available_sort_by","in_out","list","attr_ids = []
+mag_1324_erp_procat_10,magento1324,product.model_product_category,name,,in_out,function,unicode,,"result=[('name',ifield or 'UNDEFINED'),('magento_exportable',True)]","result=[('name',record['name'])]"
+mag_1324_erp_procat_11,magento1324,product.model_product_category,is_anchor,,in_out,function,unicode,,"result=[('is_anchor',ifield and bool(eval(ifield)) or False)]","result=[('is_anchor',record['is_anchor'])]"
+mag_1324_erp_procat_12,magento1324,product.model_product_category,available_sort_by,,in_out,function,list,,"attr_ids = []
 cat_attr_obj = self.pool.get('magerp.product_category_attribute_options')
 if ifield:
     for val in ifield:
@@ -92,14 +93,14 @@
     for cat_attr_option in self.pool.get('magerp.product_category_attribute_options').browse(cr, uid, record['available_sort_by'], context=context):
         res.append(cat_attr_option.value)
 result=[('available_sort_by', res)]"
-"mag_1324_erp_procat_13","magento1324","product.model_product_category","default_sort_by","in_out","unicode","if ifield:
+mag_1324_erp_procat_13,magento1324,product.model_product_category,default_sort_by,,in_out,function,unicode,,"if ifield:
     att_id = self.pool.get('magerp.product_category_attribute_options').get_create_option_id(cr, uid, ifield,'sort_by', context=context)
 else:
     att_id = self.pool.get('magerp.product_category_attribute_options').get_create_option_id(cr, uid, 'None','sort_by', context=context)
 result=[('default_sort_by',att_id)]","cat_attr_option = self.pool.get('magerp.product_category_attribute_options').browse(cr, uid, record['default_sort_by'][0], context=context)
 result=[('default_sort_by', cat_attr_option.value)]"
-"mag_1324_erp_procat_14","magento1324","product.model_product_category","updated_at","in","unicode","result=[('magerp_stamp',ifield)]",
-"mag_1324_erp_procat_15","magento1324","product.model_product_category","image","in_out","unicode","image_binary = False
+mag_1324_erp_procat_14,magento1324,product.model_product_category,updated_at,,in,function,unicode,,"result=[('magerp_stamp',ifield)]",
+mag_1324_erp_procat_15,magento1324,product.model_product_category,image,,in_out,function,unicode,,"image_binary = False
 if ifield and not ifield=='None':
 	try:
 		image_binary = conn.call('ol_catalog_category_media.info', [int(data['category_id'])])
@@ -115,52 +116,52 @@
 	result = [('image',record['image_name'])]
 else:
 	result=[]"
-"mag_1324_erp_procat_16","magento1324","product.model_product_category","include_in_menu","in_out","unicode","result=[('include_in_menu', ifield and (eval(ifield)) or False)]","result=[('include_in_menu',record['include_in_menu'])]"
-"mag_1324_erp_procat_17","magento1324","product.model_product_category","page_layout","in_out","unicode","if ifield:
+mag_1324_erp_procat_16,magento1324,product.model_product_category,include_in_menu,,in_out,function,unicode,,"result=[('include_in_menu', ifield and (eval(ifield)) or False)]","result=[('include_in_menu',record['include_in_menu'])]"
+mag_1324_erp_procat_17,magento1324,product.model_product_category,page_layout,,in_out,function,unicode,,"if ifield:
     att_id = self.pool.get('magerp.product_category_attribute_options').get_create_option_id(cr, uid, ifield,'page_layout', context=context)
 else:
     att_id = self.pool.get('magerp.product_category_attribute_options').get_create_option_id(cr, uid, 'None','page_layout', context=context)
 result=[('page_layout',att_id)]","result=[('page_layout', record['page_layout'][1] or '')]"
-"mag_1324_erp_attrgrp_2","magento1324","model_magerp_product_attribute_groups","attribute_set_id","in_out","int","result=[('attribute_set_id', ifield)]","result=[('attribute_set_id', record['attribute_set_id'])]"
-"mag_1324_erp_attrgrp_3","magento1324","model_magerp_product_attribute_groups","attribute_group_name","in_out","unicode","result=[('attribute_group_name', ifield)]","result=[('attribute_group_name', record['attribute_group_name'])]"
-"mag_1324_erp_attrgrp_4","magento1324","model_magerp_product_attribute_groups","sort_order","in_out","int","result=[('sort_order', ifield)]","result=[('sort_order', record['sort_order'])]"
-"mag_1324_erp_attrgrp_5","magento1324","model_magerp_product_attribute_groups","default_id","in_out","int","result=[('default_id', ifield)]","result=[('default_id', record['default_id'])]"
-"mag_1324_erp_attrset_1","magento1324","model_magerp_product_attribute_set","attribute_set_id","in_out","int","result=[('magento_id', ifield)]","result=[('attribute_set_id', record['magento_id'])]"
-"mag_1324_erp_attrset_2","magento1324","model_magerp_product_attribute_set","sort_order","in_out","int","result=[('sort_order', ifield)]","result=[('sort_order', record['sort_order'])]"
-"mag_1324_erp_attrset_3","magento1324","model_magerp_product_attribute_set","attribute_set_name","in_out","unicode","result=[('attribute_set_name', ifield)]","result=[('attribute_set_name', record['attribute_set_name'])]"
-"mag_1324_erp_attr_1","magento1324","model_magerp_product_attributes","attribute_code","in_out","unicode","result=[('attribute_code', ifield)]","result=[('code', record['attribute_code'])]"
-"mag_1324_erp_attr_2","magento1324","model_magerp_product_attributes","attribute_id","in_out","int","result=[('magento_id', ifield)]",
-"mag_1324_erp_attr_3","magento1324","model_magerp_product_attributes","frontend_input","in_out","unicode","result=[('frontend_input', ifield)]","result=[('frontend_input', record['frontend_input'])]"
-"mag_1324_erp_attr_4","magento1324","model_magerp_product_attributes","frontend_class","in_out","unicode","result=[('frontend_class', ifield)]","result=[('frontend_class', record['frontend_class'])]"
-"mag_1324_erp_attr_5","magento1324","model_magerp_product_attributes","backend_model","in_out","unicode","result=[('backend_model', ifield)]","result=[('backend_model', record['backend_model'])]"
-"mag_1324_erp_attr_6","magento1324","model_magerp_product_attributes","backend_type","in_out","unicode","result=[('backend_type', ifield)]","result=[('backend_type', record['backend_type'])]"
-"mag_1324_erp_attr_7","magento1324","model_magerp_product_attributes","frontend_label","in_out","unicode","result=[('frontend_label', ifield)]","result=[('frontend_label', record['frontend_label'])]"
-"mag_1324_erp_attr_8","magento1324","model_magerp_product_attributes","is_visible_in_advanced_search","in_out","unicode","result=[('is_visible_in_advanced_search', bool(eval(ifield)))]","result=[('is_visible_in_advanced_search', record['is_visible_in_advanced_search'])]"
-"mag_1324_erp_attr_9","magento1324","model_magerp_product_attributes","is_global","in_out","unicode","result=[('is_global', bool(eval(ifield)))]","result=[('is_global', record['is_global'])]"
-"mag_1324_erp_attr_10","magento1324","model_magerp_product_attributes","is_filterable","in_out","unicode","result=[('is_filterable', bool(eval(ifield)))]","result=[('is_filterable', record['is_filterable'])]"
-"mag_1324_erp_attr_11","magento1324","model_magerp_product_attributes","is_comparable","in_out","unicode","result=[('is_comparable', bool(eval(ifield)))]","result=[('is_comparable', record['is_comparable'])]"
-"mag_1324_erp_attr_12","magento1324","model_magerp_product_attributes","is_visible","in_out","unicode","result=[('is_visible', bool(eval(ifield)))]","result=[('is_visible', record['is_visible'])]"
-"mag_1324_erp_attr_13","magento1324","model_magerp_product_attributes","is_searchable","in_out","unicode","result=[('is_searchable', bool(eval(ifield)))]","result=[('is_searchable', record['is_searchable'])]"
-"mag_1324_erp_attr_14","magento1324","model_magerp_product_attributes","is_user_defined","in_out","unicode","result=[('is_user_defined', bool(eval(ifield)))]","result=[('is_user_defined', record['is_user_defined'])]"
-"mag_1324_erp_attr_15","magento1324","model_magerp_product_attributes","is_configurable","in_out","unicode","result=[('is_configurable', bool(eval(ifield)))]","result=[('is_configurable', record['is_configurable'])]"
-"mag_1324_erp_attr_16","magento1324","model_magerp_product_attributes","is_visible_on_front","in_out","unicode","result=[('is_visible_on_front', bool(eval(ifield)))]","result=[('is_visible_on_front', record['is_visible_on_front'])]"
-"mag_1324_erp_attr_17","magento1324","model_magerp_product_attributes","is_used_for_price_rules","in_out","unicode","result=[('is_used_for_price_rules', bool(eval(ifield)))]","result=[('is_used_for_price_rules', record['is_used_for_price_rules'])]"
-"mag_1324_erp_attr_18","magento1324","model_magerp_product_attributes","is_unique","in_out","unicode","result=[('is_unique', bool(eval(ifield)))]","result=[('is_unique', record['is_unique'])]"
-"mag_1324_erp_attr_19","magento1324","model_magerp_product_attributes","is_required","in_out","unicode","result=[('is_required', bool(eval(ifield)))]","result=[('is_required', record['is_required'])]"
-"mag_1324_erp_attr_20","magento1324","model_magerp_product_attributes","position","in_out","int","result=[('position', ifield)]","result=[('position', record['position'])]"
-"mag_1324_erp_attr_21","magento1324","model_magerp_product_attributes","attribute_set_info","in_out","unicode","result=[('attribute_set_info', ifield)]","result=[('attribute_set_info', record['attribute_set_info'])]"
-"mag_1324_erp_attr_22","magento1324","model_magerp_product_attributes","default_value","in_out","unicode","result=[('default_value', ifield)]","result=[('default_value', record['default_value'])]"
-"mag_1324_erp_attr_23","magento1324","model_magerp_product_attributes","note","in_out","unicode","result=[('note', ifield)]","result=[('note', record['note'])]"
-"mag_1324_erp_attr_24","magento1324","model_magerp_product_attributes","entity_type_id","in_out","int","result=[('entity_type_id', ifield)]","result=[('entity_type_id', record['entity_type_id'])]"
-"mag_1324_erp_attr_25","magento1324","model_magerp_product_attributes","apply_to","in_out","unicode","result=[('apply_to', str(ifield))]","result=[('apply_to', eval(record['%s']))]"
-"mag_1324_erp_prd_1","magento1324","product.model_product_product","url_key","in_out","unicode","result=[('x_magerp_url_key',ifield)]","if context.get('export_url', False) :
+mag_1324_erp_attrgrp_2,magento1324,model_magerp_product_attribute_groups,attribute_set_id,,in_out,function,int,,"result=[('attribute_set_id', ifield)]","result=[('attribute_set_id', record['attribute_set_id'])]"
+mag_1324_erp_attrgrp_3,magento1324,model_magerp_product_attribute_groups,attribute_group_name,,in_out,function,unicode,,"result=[('attribute_group_name', ifield)]","result=[('attribute_group_name', record['attribute_group_name'])]"
+mag_1324_erp_attrgrp_4,magento1324,model_magerp_product_attribute_groups,sort_order,,in_out,function,int,,"result=[('sort_order', ifield)]","result=[('sort_order', record['sort_order'])]"
+mag_1324_erp_attrgrp_5,magento1324,model_magerp_product_attribute_groups,default_id,,in_out,function,int,,"result=[('default_id', ifield)]","result=[('default_id', record['default_id'])]"
+mag_1324_erp_attrset_1,magento1324,model_magerp_product_attribute_set,attribute_set_id,,in_out,function,int,,"result=[('magento_id', ifield)]","result=[('attribute_set_id', record['magento_id'])]"
+mag_1324_erp_attrset_2,magento1324,model_magerp_product_attribute_set,sort_order,,in_out,function,int,,"result=[('sort_order', ifield)]","result=[('sort_order', record['sort_order'])]"
+mag_1324_erp_attrset_3,magento1324,model_magerp_product_attribute_set,attribute_set_name,,in_out,function,unicode,,"result=[('attribute_set_name', ifield)]","result=[('attribute_set_name', record['attribute_set_name'])]"
+mag_1324_erp_attr_1,magento1324,model_magerp_product_attributes,attribute_code,,in_out,function,unicode,,"result=[('attribute_code', ifield)]","result=[('code', record['attribute_code'])]"
+mag_1324_erp_attr_2,magento1324,model_magerp_product_attributes,attribute_id,,in_out,function,int,,"result=[('magento_id', ifield)]",
+mag_1324_erp_attr_3,magento1324,model_magerp_product_attributes,frontend_input,,in_out,function,unicode,,"result=[('frontend_input', ifield)]","result=[('frontend_input', record['frontend_input'])]"
+mag_1324_erp_attr_4,magento1324,model_magerp_product_attributes,frontend_class,,in_out,function,unicode,,"result=[('frontend_class', ifield)]","result=[('frontend_class', record['frontend_class'])]"
+mag_1324_erp_attr_5,magento1324,model_magerp_product_attributes,backend_model,,in_out,function,unicode,,"result=[('backend_model', ifield)]","result=[('backend_model', record['backend_model'])]"
+mag_1324_erp_attr_6,magento1324,model_magerp_product_attributes,backend_type,,in_out,function,unicode,,"result=[('backend_type', ifield)]","result=[('backend_type', record['backend_type'])]"
+mag_1324_erp_attr_7,magento1324,model_magerp_product_attributes,frontend_label,,in_out,function,unicode,,"result=[('frontend_label', ifield)]","result=[('frontend_label', record['frontend_label'])]"
+mag_1324_erp_attr_8,magento1324,model_magerp_product_attributes,is_visible_in_advanced_search,,in_out,function,unicode,,"result=[('is_visible_in_advanced_search', bool(eval(ifield)))]","result=[('is_visible_in_advanced_search', record['is_visible_in_advanced_search'])]"
+mag_1324_erp_attr_9,magento1324,model_magerp_product_attributes,is_global,,in_out,function,unicode,,"result=[('is_global', bool(eval(ifield)))]","result=[('is_global', record['is_global'])]"
+mag_1324_erp_attr_10,magento1324,model_magerp_product_attributes,is_filterable,,in_out,function,unicode,,"result=[('is_filterable', bool(eval(ifield)))]","result=[('is_filterable', record['is_filterable'])]"
+mag_1324_erp_attr_11,magento1324,model_magerp_product_attributes,is_comparable,,in_out,function,unicode,,"result=[('is_comparable', bool(eval(ifield)))]","result=[('is_comparable', record['is_comparable'])]"
+mag_1324_erp_attr_12,magento1324,model_magerp_product_attributes,is_visible,,in_out,function,unicode,,"result=[('is_visible', bool(eval(ifield)))]","result=[('is_visible', record['is_visible'])]"
+mag_1324_erp_attr_13,magento1324,model_magerp_product_attributes,is_searchable,,in_out,function,unicode,,"result=[('is_searchable', bool(eval(ifield)))]","result=[('is_searchable', record['is_searchable'])]"
+mag_1324_erp_attr_14,magento1324,model_magerp_product_attributes,is_user_defined,,in_out,function,unicode,,"result=[('is_user_defined', bool(eval(ifield)))]","result=[('is_user_defined', record['is_user_defined'])]"
+mag_1324_erp_attr_15,magento1324,model_magerp_product_attributes,is_configurable,,in_out,function,unicode,,"result=[('is_configurable', bool(eval(ifield)))]","result=[('is_configurable', record['is_configurable'])]"
+mag_1324_erp_attr_16,magento1324,model_magerp_product_attributes,is_visible_on_front,,in_out,function,unicode,,"result=[('is_visible_on_front', bool(eval(ifield)))]","result=[('is_visible_on_front', record['is_visible_on_front'])]"
+mag_1324_erp_attr_17,magento1324,model_magerp_product_attributes,is_used_for_price_rules,,in_out,function,unicode,,"result=[('is_used_for_price_rules', bool(eval(ifield)))]","result=[('is_used_for_price_rules', record['is_used_for_price_rules'])]"
+mag_1324_erp_attr_18,magento1324,model_magerp_product_attributes,is_unique,,in_out,function,unicode,,"result=[('is_unique', bool(eval(ifield)))]","result=[('is_unique', record['is_unique'])]"
+mag_1324_erp_attr_19,magento1324,model_magerp_product_attributes,is_required,,in_out,function,unicode,,"result=[('is_required', bool(eval(ifield)))]","result=[('is_required', record['is_required'])]"
+mag_1324_erp_attr_20,magento1324,model_magerp_product_attributes,position,,in_out,function,int,,"result=[('position', ifield)]","result=[('position', record['position'])]"
+mag_1324_erp_attr_21,magento1324,model_magerp_product_attributes,attribute_set_info,,in_out,function,unicode,,"result=[('attribute_set_info', ifield)]","result=[('attribute_set_info', record['attribute_set_info'])]"
+mag_1324_erp_attr_22,magento1324,model_magerp_product_attributes,default_value,,in_out,function,unicode,,"result=[('default_value', ifield)]","result=[('default_value', record['default_value'])]"
+mag_1324_erp_attr_23,magento1324,model_magerp_product_attributes,note,,in_out,function,unicode,,"result=[('note', ifield)]","result=[('note', record['note'])]"
+mag_1324_erp_attr_24,magento1324,model_magerp_product_attributes,entity_type_id,,in_out,function,int,,"result=[('entity_type_id', ifield)]","result=[('entity_type_id', record['entity_type_id'])]"
+mag_1324_erp_attr_25,magento1324,model_magerp_product_attributes,apply_to,,in_out,function,unicode,,"result=[('apply_to', str(ifield))]","result=[('apply_to', eval(record['%s']))]"
+mag_1324_erp_prd_1,magento1324,product.model_product_product,url_key,,in_out,function,unicode,,"result=[('x_magerp_url_key',ifield)]","if context.get('export_url', False) :
     result=[('url_key',record['x_magerp_url_key'])]"
-"mag_1324_erp_prd_2","magento1324","product.model_product_product","name","in_out","unicode","result = [('name',ifield)]","result = [('name',record['name'])]"
-"mag_1324_erp_prd_3","magento1324","product.model_product_product","description","in_out","unicode","result = [('description',ifield)]",
-"mag_1324_erp_prd_4","magento1324","product.model_product_product","short_description","in_out","unicode","result = [('description_sale',ifield)]",
-"mag_1324_erp_prd_5","magento1324","product.model_product_product","sku","in_out","unicode","result = [('magento_sku',ifield), ('default_code',ifield)]",
-"mag_1324_erp_prd_6","magento1324","product.model_product_product","weight","in_out","float","result = [('weight',ifield)]","result = [('weight',record['weight'] or 0)]"
-"mag_1324_erp_prd_7","magento1324","product.model_product_product","category_ids","in_out","list","categ_ids =[]
+mag_1324_erp_prd_2,magento1324,product.model_product_product,name,,in_out,function,unicode,,"result = [('name',ifield)]","result = [('name',record['name'])]"
+mag_1324_erp_prd_3,magento1324,product.model_product_product,description,,in_out,function,unicode,,"result = [('description',ifield)]",
+mag_1324_erp_prd_4,magento1324,product.model_product_product,short_description,,in_out,function,unicode,,"result = [('description_sale',ifield)]",
+mag_1324_erp_prd_5,magento1324,product.model_product_product,sku,,in_out,function,unicode,,"result = [('magento_sku',ifield), ('default_code',ifield)]",
+mag_1324_erp_prd_6,magento1324,product.model_product_product,weight,,in_out,function,float,,"result = [('weight',ifield)]","result = [('weight',record['weight'] or 0)]"
+mag_1324_erp_prd_7,magento1324,product.model_product_product,category_ids,,in_out,function,list,,"categ_ids =[]
 if ifield and len(ifield) > 0:
     for category_ids in ifield:
         categ_ids.append(self.pool.get('product.category').extid_to_oeid(cr, uid, category_ids, external_referential_id))
@@ -176,24 +177,24 @@
     if categ_id:
         categ_ids.append(categ_id)
 result=[('category_ids', categ_ids)]"
-"mag_1324_erp_prd_8","magento1324","product.model_product_product","price","in_out","float","result=[('list_price',ifield)]","result=[]#map later"
-"mag_1324_erp_prd_9","magento1324","product.model_product_product","cost","in_out","float","result=[('standard_price',ifield)]","result = [('cost',record['standard_price'] or 0)]"
-"mag_1324_erp_prd_10","magento1324","product.model_product_product","set","in_out","unicode","result=[('set',self.pool.get('magerp.product_attribute_set').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
-"mag_1324_erp_prd_11","magento1324","product.model_product_product","special_price","in_out","float","result = [('x_magerp_special_price',ifield)]",
-"mag_1324_erp_prd_12","magento1324","product.model_product_product","tier_price","in_out","unicode","result=[]#no mapping by default","result=[]#no mapping by default"
-"mag_1324_erp_prd_13","magento1324","product.model_product_product","minimal_price","in_out","float","result = [('x_magerp_minimal_price',ifield)]","
+mag_1324_erp_prd_8,magento1324,product.model_product_product,price,,in_out,function,float,,"result=[('list_price',ifield)]",result=[]#map later
+mag_1324_erp_prd_9,magento1324,product.model_product_product,cost,,in_out,function,float,,"result=[('standard_price',ifield)]","result = [('cost',record['standard_price'] or 0)]"
+mag_1324_erp_prd_10,magento1324,product.model_product_product,set,,in_out,function,unicode,,"result=[('set',self.pool.get('magerp.product_attribute_set').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
+mag_1324_erp_prd_11,magento1324,product.model_product_product,special_price,,in_out,function,float,,"result = [('x_magerp_special_price',ifield)]",
+mag_1324_erp_prd_12,magento1324,product.model_product_product,tier_price,,in_out,function,unicode,,result=[]#no mapping by default,result=[]#no mapping by default
+mag_1324_erp_prd_13,magento1324,product.model_product_product,minimal_price,,in_out,function,float,,"result = [('x_magerp_minimal_price',ifield)]","
 if record['x_magerp_minimal_price'] and record['x_magerp_minimal_price'] != 0:
     result = [('minimal_price',record['x_magerp_minimal_price'])]
 else:
     result = [('minimal_price',False)]"
-"mag_1324_erp_prd_14","magento1324","product.model_product_product","type_id","in_out","unicode","if ifield:
+mag_1324_erp_prd_14,magento1324,product.model_product_product,type_id,,in_out,function,unicode,,"if ifield:
     product_type_ids  = self.pool.get('magerp.product_product_type').search(cr,uid,[('product_type','=',ifield)])
     if product_type_ids:
         result = [('product_type',ifield)]","if 'product_type' in record and record['product_type']:
     result = [('type_id',record['product_type'])]
 else:
     result = [('type_id','simple')]"
-"mag_1324_erp_prd_15","magento1324","product.model_product_product","websites","in_out","list","websites_ids = []
+mag_1324_erp_prd_15,magento1324,product.model_product_product,websites,,in_out,function,list,,"websites_ids = []
 for ext_id in ifield:
     websites_ids.append(self.pool.get('external.shop.group').extid_to_oeid(cr, uid, ext_id, external_referential_id))
 
@@ -213,29 +214,29 @@
     ext_websites_ids.append(self.pool.get('external.shop.group').oeid_to_extid(cr, uid, oe_id, external_referential_id))
 
 result=[('websites', ext_websites_ids)]"
-"mag_1324_erp_prd_16","magento1324","product.model_product_product","has_options","in","unicode","result =[('x_magerp_has_options',ifield)]",""
-"magento_1324_cst_grp_1","magento1324","base.model_res_partner_category","customer_group_code","in","unicode","result=[('name',ifield)]",
-"magento_1324_cst_grp_3","magento1324","base.model_res_partner_category","tax_class_id","in","int","result=[('tax_class_id',ifield)]",
-"magento_1324_prt_adr_2","magento1324","base.model_res_partner_address","city","in_out","unicode","result=[('city',ifield)]",
-"magento_1324_prt_adr_3","magento1324","base.model_res_partner_address","fax","in_out","unicode","result=[('fax',ifield)]",
-"magento_1324_prt_adr_4","magento1324","base.model_res_partner_address","firstname","in_out","unicode","result = [('name', (data.get('company', False) and (data['company'] + ' ; ') or '') + ifield + ' ' + (data['lastname'] or '')), ('firstname', ifield), ('lastname', (data['lastname'] or ''))]",
-"magento_1324_prt_adr_6","magento1324","base.model_res_partner_address","is_active","in_out","unicode","result=[('active',bool(eval(ifield)))]",
-"magento_1324_prt_adr_7","magento1324","base.model_res_partner_address","country_id","in_out","unicode","result = self.pool.get('res.country').search(cr,uid,[('code','=',ifield)])
+mag_1324_erp_prd_16,magento1324,product.model_product_product,has_options,,in,function,unicode,,"result =[('x_magerp_has_options',ifield)]",
+magento_1324_cst_grp_1,magento1324,base.model_res_partner_category,customer_group_code,,in,function,unicode,,"result=[('name',ifield)]",
+magento_1324_cst_grp_3,magento1324,base.model_res_partner_category,tax_class_id,,in,function,int,,"result=[('tax_class_id',ifield)]",
+magento_1324_prt_adr_2,magento1324,base.model_res_partner_address,city,,in_out,function,unicode,,"result=[('city',ifield)]",
+magento_1324_prt_adr_3,magento1324,base.model_res_partner_address,fax,,in_out,function,unicode,,"result=[('fax',ifield)]",
+magento_1324_prt_adr_4,magento1324,base.model_res_partner_address,firstname,,in_out,function,unicode,,"result = [('name', (data.get('company', False) and (data['company'] + ' ; ') or '') + ifield + ' ' + data['lastname']), ('firstname', ifield), ('lastname', data['lastname'])]",
+magento_1324_prt_adr_6,magento1324,base.model_res_partner_address,is_active,,in_out,function,unicode,,"result=[('active',bool(eval(ifield)))]",
+magento_1324_prt_adr_7,magento1324,base.model_res_partner_address,country_id,,in_out,function,unicode,,"result = self.pool.get('res.country').search(cr,uid,[('code','=',ifield)])
 if result and len(result)==1:
 	result=[('country_id',result[0])]
 else:
 	result=[]
 ",
-"magento_1324_prt_adr_8","magento1324","base.model_res_partner_address","street","in_out","unicode","if ifield:
+magento_1324_prt_adr_8,magento1324,base.model_res_partner_address,street,,in_out,function,unicode,,"if ifield:
 	if len(ifield.split('\n')) ==2 :
 		result = [('street', ifield.split('\n')[0]) , ('street2', ifield.split('\n')[1])]
 	else :
 		result = [('street',ifield.replace('\\n',','))]
 else:
 	result = []",
-"magento_1324_prt_adr_9","magento1324","base.model_res_partner_address","postcode","in_out","unicode","result=[('zip',ifield)]",
-"magento_1324_prt_adr_10","magento1324","base.model_res_partner_address","telephone","in_out","unicode","result=[('phone',ifield)]",
-"magento_1324_prt_adr_11","magento1324","base.model_res_partner_address","region","in_out","unicode","if ifield:
+magento_1324_prt_adr_9,magento1324,base.model_res_partner_address,postcode,,in_out,function,unicode,,"result=[('zip',ifield)]",
+magento_1324_prt_adr_10,magento1324,base.model_res_partner_address,telephone,,in_out,function,unicode,,"result=[('phone',ifield)]",
+magento_1324_prt_adr_11,magento1324,base.model_res_partner_address,region,,in_out,function,unicode,,"if ifield:
 	result = self.pool.get('res.country.state').search(cr,uid,[('name','ilike',ifield)])
 	if result and len(result)==1:
 		result = [('state_id',result[0])]
@@ -243,44 +244,44 @@
 		result=[]
 else:
 	result=[]",
-"magento_1324_prt_adr_13","magento1324","base.model_res_partner_address","customer_id","in_out","int","result=self.pool.get('res.partner').extid_to_oeid(cr,uid,ifield,external_referential_id)
+magento_1324_prt_adr_13,magento1324,base.model_res_partner_address,customer_id,,in_out,function,int,,"result=self.pool.get('res.partner').extid_to_oeid(cr,uid,ifield,external_referential_id)
 if result:
 	result=[('partner_id',result)]
 else:
 	result=[('partner_id',False)]",
-"magento_1324_prt_adr_14","magento1324","base.model_res_partner_address","address_type","in_out","unicode","if ifield=='billing':
+magento_1324_prt_adr_14,magento1324,base.model_res_partner_address,address_type,,in_out,function,unicode,,"if ifield=='billing':
 	result=[('type','invoice')]
 elif ifield=='shipping':
 	result=[('type','delivery')]
 else:
 	result=[]",
-"magento_1324_prt_adr_15","magento1324","base.model_res_partner_address","email","in_out","unicode","result=[('email',ifield)]",
-"magento_1324_prt_2","magento1324","base.model_res_partner","group_id","in_out","int","if ifield:
+magento_1324_prt_adr_15,magento1324,base.model_res_partner_address,email,,in_out,function,unicode,,"result=[('email',ifield)]",
+magento_1324_prt_2,magento1324,base.model_res_partner,group_id,,in_out,function,int,,"if ifield:
 	result=self.pool.get('res.partner.category').extid_to_oeid(cr,uid,ifield,external_referential_id)
 	if result:
 		result=[('group_id',result)]",
-"magento_1324_prt_3","magento1324","base.model_res_partner","store_id","in_out","int","if ifield:
+magento_1324_prt_3,magento1324,base.model_res_partner,store_id,,in_out,function,int,,"if ifield:
 	result=self.pool.get('magerp.storeviews').extid_to_oeid(cr,uid,ifield,external_referential_id)
 	if result:
 		lang = self.pool.get('magerp.storeviews').browse(cr, uid, result).lang_id
 		result=[('store_id',result),('lang',lang and lang.code or False)]",
-"magento_1324_prt_4","magento1324","base.model_res_partner","website_id","in_out","int","if ifield:
+magento_1324_prt_4,magento1324,base.model_res_partner,website_id,,in_out,function,int,,"if ifield:
 	result=self.pool.get('external.shop.group').extid_to_oeid(cr,uid,ifield,external_referential_id)
 	if result:
 		result=[('website_id',result)]",
-"magento_1324_prt_5","magento1324","base.model_res_partner","created_in","in_out","unicode","result=[('created_in',ifield)]",
-"magento_1324_prt_6","magento1324","base.model_res_partner","created_at","in_out","unicode","result=[('created_at',ifield)]",
-"magento_1324_prt_7","magento1324","base.model_res_partner","updated_at","in_out","unicode","result=[('updated_at',ifield)]",
-"magento_1324_prt_8","magento1324","base.model_res_partner","firstname","in_out","unicode","result = [('name', ifield + ' ' + data['lastname'])]","add_id = self.browse(cr, uid, record['id'])
+magento_1324_prt_5,magento1324,base.model_res_partner,created_in,,in_out,function,unicode,,"result=[('created_in',ifield)]",
+magento_1324_prt_6,magento1324,base.model_res_partner,created_at,,in_out,function,unicode,,"result=[('created_at',ifield)]",
+magento_1324_prt_7,magento1324,base.model_res_partner,updated_at,,in_out,function,unicode,,"result=[('updated_at',ifield)]",
+magento_1324_prt_8,magento1324,base.model_res_partner,firstname,,in_out,function,unicode,,"result = [('name', ifield + ' ' + data['lastname'])]","add_id = self.browse(cr, uid, record['id'])
 fn = add_id.address[0].firstname
 ln = add_id.address[0].lastname
 result=[('firstname', fn), ('lastname', ln)]"
-"magento_1324_prt_10","magento1324","base.model_res_partner","email","in_out","unicode","result=[('emailid',ifield)]",
-"magento_1324_prt_11","magento1324","base.model_res_partner","taxvat","in_out","unicode","if ifield:
+magento_1324_prt_10,magento1324,base.model_res_partner,email,,in_out,function,unicode,,"result=[('emailid',ifield)]",
+magento_1324_prt_11,magento1324,base.model_res_partner,taxvat,,in_out,function,unicode,,"if ifield:
 	result=[('mag_vat',ifield)]
 else:
 	result=[]",
-"magento_1324_prt_12","magento1324","base.model_res_partner","dob","in_out","unicode","if ifield:
+magento_1324_prt_12,magento1324,base.model_res_partner,dob,,in_out,function,unicode,,"if ifield:
 	result =[('mag_birthday',ifield[:10])]
 else:
 	result=[]",

=== modified file 'magentoerpconnect/settings/1.5.0.0/external.mapping.template.csv'
--- magentoerpconnect/settings/1.5.0.0/external.mapping.template.csv	2011-11-27 19:01:32 +0000
+++ magentoerpconnect/settings/1.5.0.0/external.mapping.template.csv	2012-03-27 09:40:33 +0000
@@ -7,7 +7,7 @@
 "magento_1500_pro_cat","magento1500","product.model_product_category","category.list","category.info","catalog_category.update","catalog_category.create",,"category_id"
 "magento_1500_attr_grp","magento1500","model_magerp_product_attribute_groups","ol_catalog_product_attribute_group.list","ol_catalog_product_attribute_group.list",,,,"attribute_group_id"
 "magento_1500_attr_set","magento1500","model_magerp_product_attribute_set","ol_catalog_product_attributeset.list",,,,,"attribute_set_id"
-"magento_1500_attr","magento1500","model_magerp_product_attributes","ol_catalog_product_attribute.list",,,,,"magento_id"
+"magento_1500_attr","magento1500","model_magerp_product_attributes","ol_catalog_product_attribute.list",,,,,"attribute_id"
 "magento_1500_prd","magento1500","product.model_product_product","catalog_product.list","catalog_product.info","ol_catalog_product.update","ol_catalog_product.create",,"product_id"
 "magento_1500_cst_grp","magento1500","base.model_res_partner_category","ol_customer_groups.list",,,,,"customer_group_id"
 "magento_1500_prt_adr","magento1500","base.model_res_partner_address","ol_customer_address.list","ol_customer_address.info",,,,"customer_address_id"

=== modified file 'magentoerpconnect/settings/1.5.0.0/external.mappinglines.template.csv'
--- magentoerpconnect/settings/1.5.0.0/external.mappinglines.template.csv	2011-12-30 07:48:40 +0000
+++ magentoerpconnect/settings/1.5.0.0/external.mappinglines.template.csv	2012-03-27 09:40:33 +0000
@@ -1,24 +1,24 @@
-"id","type_id:id","model_id:id","external_field","type","external_type","in_function","out_function"
-"mag_1500_erp_s_name","magento1500","base_sale_multichannels.model_external_shop_group","name","in_out","unicode","result=[('name',ifield)]","result=[('name',record['name'])]"
-"mag_1500_erp_s_code","magento1500","base_sale_multichannels.model_external_shop_group","code","in_out","unicode","result=[('code',ifield)]",
-"mag_1500_erp_s_web","magento1500","base_sale_multichannels.model_external_shop_group","website_id","in_out","int","result=[('website_id',ifield)]",
-"mag_1500_erp_s_isa","magento1500","base_sale_multichannels.model_external_shop_group","is_default","in_out","unicode","result=[('is_default',bool(eval(ifield)))]",
-"mag_1500_erp_s_stord","magento1500","base_sale_multichannels.model_external_shop_group","sort_order","in_out","int","result=[('sort_order',ifield)]",
-"mag_1500_erp_s_gpid","magento1500","base_sale_multichannels.model_external_shop_group","default_group_id","in_out","int","result=[('default_shop_integer_id',ifield)]",
-"mag_1500_erp_sv_name","magento1500","model_magerp_storeviews","name","in_out","unicode","result=[('name',ifield)]","result=[('name',record['name'])]"
-"mag_1500_erp_sv_code","magento1500","model_magerp_storeviews","code","in_out","unicode","result=[('code',ifield)]",
-"mag_1500_erp_sv_sg","magento1500","model_magerp_storeviews","website_id","in_out","int","result=[('website_id',self.pool.get('external.shop.group').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
-"mag_1500_erp_sv_isa","magento1500","model_magerp_storeviews","is_active","in_out","unicode","result=[('is_active',bool(eval(ifield)))]",
-"mag_1500_erp_sv_stord","magento1500","model_magerp_storeviews","sort_order","in_out","int","result=[('sort_order',ifield)]",
-"mag_1500_erp_sv_gpid","magento1500","model_magerp_storeviews","group_id","in_out","int","result=[('shop_id',self.pool.get('sale.shop').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
-"mag_1500_erp_st_name","magento1500","sale.model_sale_shop","name","in_out","unicode","result=[('name',ifield)]","result=[('name',record['name'])]"
-"mag_1500_erp_st_gpid","magento1500","sale.model_sale_shop","group_id","in_out","int","result=[('group_id',ifield)]",
-"mag_1500_erp_st_grp","magento1500","sale.model_sale_shop","website_id","in_out","int","result=[('shop_group_id',self.pool.get('external.shop.group').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
-"mag_1500_erp_st_default_st","magento1500","sale.model_sale_shop","default_store_id","in_out","int","result=[('default_storeview_integer_id',ifield)]",
-"mag_1500_erp_st_root_categ","magento1500","sale.model_sale_shop","root_category_id","in_out","int","result=[('root_category_id',ifield)]",
-"mag_1500_erp_so_name","magento1500","sale.model_sale_order","increment_id","in_out","unicode","result=[('magento_incrementid',str(ifield)), ('name','mag_' + str(ifield))]",
-"mag_1500_erp_so_total_amount","magento1500","sale.model_sale_order","grand_total","in_out","float","result=[('ext_total_amount',str(ifield))]",
-"mag_1500_erp_so_carrier_id","magento1500","sale.model_sale_order","shipping_method","in_out","unicode","if ifield:
+id,type_id:id,model_id:id,external_field,field_id:id,type,evaluation_type,external_type,child_mapping_id:id,in_function,out_function
+mag_1500_erp_s_name,magento1500,base_sale_multichannels.model_external_shop_group,name,,in_out,function,unicode,,"result=[('name',ifield)]","result=[('name',record['name'])]"
+mag_1500_erp_s_code,magento1500,base_sale_multichannels.model_external_shop_group,code,,in_out,function,unicode,,"result=[('code',ifield)]",
+mag_1500_erp_s_web,magento1500,base_sale_multichannels.model_external_shop_group,website_id,,in_out,function,int,,"result=[('website_id',ifield)]",
+mag_1500_erp_s_isa,magento1500,base_sale_multichannels.model_external_shop_group,is_default,,in_out,function,unicode,,"result=[('is_default',bool(eval(ifield)))]",
+mag_1500_erp_s_stord,magento1500,base_sale_multichannels.model_external_shop_group,sort_order,,in_out,function,int,,"result=[('sort_order',ifield)]",
+mag_1500_erp_s_gpid,magento1500,base_sale_multichannels.model_external_shop_group,default_group_id,,in_out,function,int,,"result=[('default_shop_integer_id',ifield)]",
+mag_1500_erp_sv_name,magento1500,model_magerp_storeviews,name,,in_out,function,unicode,,"result=[('name',ifield)]","result=[('name',record['name'])]"
+mag_1500_erp_sv_code,magento1500,model_magerp_storeviews,code,,in_out,function,unicode,,"result=[('code',ifield)]",
+mag_1500_erp_sv_sg,magento1500,model_magerp_storeviews,website_id,,in_out,function,int,,"result=[('website_id',self.pool.get('external.shop.group').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
+mag_1500_erp_sv_isa,magento1500,model_magerp_storeviews,is_active,,in_out,function,unicode,,"result=[('is_active',bool(eval(ifield)))]",
+mag_1500_erp_sv_stord,magento1500,model_magerp_storeviews,sort_order,,in_out,function,int,,"result=[('sort_order',ifield)]",
+mag_1500_erp_sv_gpid,magento1500,model_magerp_storeviews,group_id,,in_out,function,int,,"result=[('shop_id',self.pool.get('sale.shop').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
+mag_1500_erp_st_name,magento1500,sale.model_sale_shop,name,,in_out,function,unicode,,"result=[('name',ifield)]","result=[('name',record['name'])]"
+mag_1500_erp_st_gpid,magento1500,sale.model_sale_shop,group_id,,in_out,function,int,,"result=[('group_id',ifield)]",
+mag_1500_erp_st_grp,magento1500,sale.model_sale_shop,website_id,,in_out,function,int,,"result=[('shop_group_id',self.pool.get('external.shop.group').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
+mag_1500_erp_st_default_st,magento1500,sale.model_sale_shop,default_store_id,,in_out,function,int,,"result=[('default_storeview_integer_id',ifield)]",
+mag_1500_erp_st_root_categ,magento1500,sale.model_sale_shop,root_category_id,,in_out,function,int,,"result=[('root_category_id',ifield)]",
+mag_1500_erp_so_name,magento1500,sale.model_sale_order,increment_id,,in_out,function,unicode,,"result=[('magento_incrementid',str(ifield)), ('name','mag_' + str(ifield))]",
+mag_1500_erp_so_total_amount,magento1500,sale.model_sale_order,grand_total,,in_out,function,float,,"result=[('ext_total_amount',str(ifield))]",
+mag_1500_erp_so_carrier_id,magento1500,sale.model_sale_order,shipping_method,,in_out,function,unicode,,"if ifield:
     carrier_ids = self.pool.get('delivery.carrier').search(cr, uid, [('magento_code', '=', ifield)])
     if carrier_ids:
         result=[('carrier_id', carrier_ids[0])]
@@ -28,13 +28,15 @@
         model, product_id = model_data_obj.get_object_reference(cr, uid, 'base_sale_multichannels', 'product_product_shipping')
         carrier_id = self.pool.get('delivery.carrier').create(cr, uid, {'partner_id' : fake_partner_id, 'product_id' : product_id, 'name' : ifield, 'magento_code' : ifield})
         result=[('carrier_id', carrier_id)]",
-"mag_1500_erp_so_pay","magento1500","sale.model_sale_order","payment","in_out","unicode","
+mag_1500_erp_so_pay,magento1500,sale.model_sale_order,payment,,in_out,function,unicode,,"
 payments_mapping = {'checkmo': 'manual', 'ccsave': 'prepaid', 'free':'prepaid','googlecheckout':'prepaid','paypayl_express':'prepaid', 'paybox_system': 'prepaid', 'paypal_standard': 'prepaid', 'cashondelivery': 'manual', 'servired_standard': 'prepaid', 'bbva': 'prepaid', 'cofidis': 'prepaid'}
 ifield=eval(ifield)
 result=[('order_policy', ifield['method'] in payments_mapping and payments_mapping[ifield['method']] or 'prepaid'), ('ext_payment_method', ifield['method'])]",
-"mag_1500_erp_soline_name","magento1500","sale.model_sale_order_line","name","in_out","unicode","result=[('name', ifield)]
+
+mag_1500_erp_so_item,magento1500,sale.model_sale_order,items,sale.field_sale_order_order_line,in,sub-mapping,dict,magento_1500_order_line,,
+"mag_1500_erp_soline_name","magento1500","sale.model_sale_order_line","name",,"in_out","function","unicode",,"result=[('name', ifield)]
 ",
-"Mag_1500_erp_soline_note","magento1324","sale.model_sale_order_line","product_options","in","unicode","if ifield:
+"Mag_1500_erp_soline_note","magento1324","sale.model_sale_order_line","product_options",,"in","function","unicode",,"if ifield:
     import re
     options_label = []
     clean = re.sub('\w:\w:|\w:\w+;', '', ifield)
@@ -45,18 +47,18 @@
 	
     result=[('notes',  """".join(options_label).replace('""""', '\n').replace('""', ''))]
 ",
-"mag_1500_erp_soline_pid","magento1500","sale.model_sale_order_line","product_id","in_out","unicode","context['alternative_key'] = data['sku']
+mag_1500_erp_soline_pid,magento1500,sale.model_sale_order_line,product_id,,in_out,function,unicode,,"context['alternative_key'] = data['sku']
 result=[('product_id',self.pool.get('product.product').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
-"mag_1500_erp_soline_uomqty","magento1500","sale.model_sale_order_line","qty_ordered","in_out","unicode","result=[('product_uom_qty',ifield)]",
-"mag_1500_erp_soline_uosqty","magento1500","sale.model_sale_order_line","qty_ordered","in","unicode","result=[('product_uos_qty',ifield)]",
-"mag_1500_erp_soline_price","magento1500","sale.model_sale_order_line","price","in","unicode","if context.get('price_is_tax_included', False):             
+mag_1500_erp_soline_uomqty,magento1500,sale.model_sale_order_line,qty_ordered,,in_out,function,unicode,,"result=[('product_uom_qty',ifield)]",
+mag_1500_erp_soline_uosqty,magento1500,sale.model_sale_order_line,qty_ordered,,in,function,unicode,,"result=[('product_uos_qty',ifield)]",
+mag_1500_erp_soline_price,magento1500,sale.model_sale_order_line,price,,in,function,unicode,,"if context.get('price_is_tax_included', False):             
     result=[('price_unit', (float(data['row_total']) + float(data['tax_amount']))/float(data['qty_ordered']))]
 else:
     result=[('price_unit', float(data['row_total'])/float(data['qty_ordered']))]",
-"mag_1500_erp_soline_disc","magento1500","sale.model_sale_order_line","discount_amount","in","float","if ifield:
+mag_1500_erp_soline_disc,magento1500,sale.model_sale_order_line,discount_amount,,in,function,float,,"if ifield:
     result=[('discount', float(data['price']) != 0 and float(data['qty_ordered']) != 0 and float(100*ifield)/(float(data['price'])*float(data['qty_ordered'])) or 0)]",
-"mag_1500_erp_procat_2","magento1500","product.model_product_category","level","in","int","result=[('sequence',ifield),('level',ifield)]",
-"mag_1500_erp_procat_3","magento1500","product.model_product_category","parent_id","in_out","int","record_id = self.pool.get('ir.model.data').search(cr, uid, [('model', '=', self._name), ('name', '=', self.prefixed_id(ifield))])
+mag_1500_erp_procat_2,magento1500,product.model_product_category,level,,in,function,int,,"result=[('sequence',ifield),('level',ifield)]",
+mag_1500_erp_procat_3,magento1500,product.model_product_category,parent_id,,in_out,function,int,,"record_id = self.pool.get('ir.model.data').search(cr, uid, [('model', '=', self._name), ('name', '=', self.prefixed_id(ifield))])
 parent_id = False
 if record_id:
 	parent_rec = self.pool.get('ir.model.data').read(cr,uid,record_id[0],[])
@@ -69,16 +71,16 @@
 		magento_parent_id = self.oeid_to_extid(cr, uid, record.get('parent_id')[0], external_referential_id)
 if magento_parent_id:
 	result = [('parent_id',magento_parent_id)]"
-"mag_1500_erp_procat_4","magento1500","product.model_product_category","is_active","in_out","unicode","result=[('is_active',ifield and (eval(ifield)) or False)]","result=[('is_active',record['is_active'])]"
-"mag_1500_erp_procat_5","magento1500","product.model_product_category","description","in_out","unicode","result=[('description',ifield)]","result=[('description',record['description'])]"
-"mag_1500_erp_procat_6","magento1500","product.model_product_category","meta_title","in_out","unicode","result=[('meta_title',ifield)]","result=[('meta_title',record['meta_title'])]"
-"mag_1500_erp_procat_7","magento1500","product.model_product_category","meta_keywords","in_out","unicode","result=[('meta_keywords',ifield)]","result=[('meta_keywords',record['meta_keywords'])]"
-"mag_1500_erp_procat_8","magento1500","product.model_product_category","meta_description","in_out","unicode","result=[('meta_description',ifield)]","result=[('meta_description',record['meta_description'])]"
-"mag_1500_erp_procat_9","magento1500","product.model_product_category","url_key","in_out","unicode","result=[('url_key',ifield)]","if context.get('export_url', False) :
+mag_1500_erp_procat_4,magento1500,product.model_product_category,is_active,,in_out,function,unicode,,"result=[('is_active',ifield and (eval(ifield)) or False)]","result=[('is_active',record['is_active'])]"
+mag_1500_erp_procat_5,magento1500,product.model_product_category,description,,in_out,function,unicode,,"result=[('description',ifield)]","result=[('description',record['description'])]"
+mag_1500_erp_procat_6,magento1500,product.model_product_category,meta_title,,in_out,function,unicode,,"result=[('meta_title',ifield)]","result=[('meta_title',record['meta_title'])]"
+mag_1500_erp_procat_7,magento1500,product.model_product_category,meta_keywords,,in_out,function,unicode,,"result=[('meta_keywords',ifield)]","result=[('meta_keywords',record['meta_keywords'])]"
+mag_1500_erp_procat_8,magento1500,product.model_product_category,meta_description,,in_out,function,unicode,,"result=[('meta_description',ifield)]","result=[('meta_description',record['meta_description'])]"
+mag_1500_erp_procat_9,magento1500,product.model_product_category,url_key,,in_out,function,unicode,,"result=[('url_key',ifield)]","if context.get('export_url', False) :
     result=[('url_key',record['url_key'])]"
-"mag_1500_erp_procat_10","magento1500","product.model_product_category","name","in_out","unicode","result=[('name',ifield or 'UNDEFINED'),('magento_exportable',True)]","result=[('name',record['name'])]"
-"mag_1500_erp_procat_11","magento1500","product.model_product_category","is_anchor","in_out","unicode","result=[('is_anchor',ifield and bool(eval(ifield)) or False)]","result=[('is_anchor',record['is_anchor'])]"
-"mag_1500_erp_procat_12","magento1500","product.model_product_category","available_sort_by","in_out","unicode","attr_ids = []
+mag_1500_erp_procat_10,magento1500,product.model_product_category,name,,in_out,function,unicode,,"result=[('name',ifield or 'UNDEFINED'),('magento_exportable',True)]","result=[('name',record['name'])]"
+mag_1500_erp_procat_11,magento1500,product.model_product_category,is_anchor,,in_out,function,unicode,,"result=[('is_anchor',ifield and bool(eval(ifield)) or False)]","result=[('is_anchor',record['is_anchor'])]"
+mag_1500_erp_procat_12,magento1500,product.model_product_category,available_sort_by,,in_out,function,unicode,,"attr_ids = []
 cat_attr_obj = self.pool.get('magerp.product_category_attribute_options')
 if ifield:
     for val in ifield:
@@ -92,14 +94,14 @@
     for cat_attr_option in self.pool.get('magerp.product_category_attribute_options').browse(cr, uid, record['available_sort_by'], context=context):
         res.append(cat_attr_option.value)
 result=[('available_sort_by', res)]"
-"mag_1500_erp_procat_13","magento1500","product.model_product_category","default_sort_by","in_out","unicode","if ifield:
+mag_1500_erp_procat_13,magento1500,product.model_product_category,default_sort_by,,in_out,function,unicode,,"if ifield:
     att_id = self.pool.get('magerp.product_category_attribute_options').get_create_option_id(cr, uid, ifield,'sort_by', context=context)
 else:
     att_id = self.pool.get('magerp.product_category_attribute_options').get_create_option_id(cr, uid, 'None','sort_by', context=context)
 result=[('default_sort_by',att_id)]","cat_attr_option = self.pool.get('magerp.product_category_attribute_options').browse(cr, uid, record['default_sort_by'][0], context=context)
 result=[('default_sort_by', cat_attr_option.value)]"
-"mag_1500_erp_procat_14","magento1500","product.model_product_category","updated_at","in","unicode","result=[('magerp_stamp',ifield)]",
-"mag_1500_erp_procat_15","magento1500","product.model_product_category","image","in_out","unicode","image_binary = False
+mag_1500_erp_procat_14,magento1500,product.model_product_category,updated_at,,in,function,unicode,,"result=[('magerp_stamp',ifield)]",
+mag_1500_erp_procat_15,magento1500,product.model_product_category,image,,in_out,function,unicode,,"image_binary = False
 if ifield and not ifield=='None':
 	try:
 		image_binary = conn.call('ol_catalog_category_media.info', [int(data['category_id'])])
@@ -115,52 +117,52 @@
 	result = [('image',record['image_name'])]
 else:
 	result=[]"
-"mag_1500_erp_procat_16","magento1500","product.model_product_category","include_in_menu","in_out","unicode","result=[('include_in_menu', ifield and (eval(ifield)) or False)]","result=[('include_in_menu',record['include_in_menu'])]"
-"mag_1500_erp_procat_17","magento1500","product.model_product_category","page_layout","in_out","unicode","if ifield:
+mag_1500_erp_procat_16,magento1500,product.model_product_category,include_in_menu,,in_out,function,unicode,,"result=[('include_in_menu', ifield and (eval(ifield)) or False)]","result=[('include_in_menu',record['include_in_menu'])]"
+mag_1500_erp_procat_17,magento1500,product.model_product_category,page_layout,,in_out,function,unicode,,"if ifield:
     att_id = self.pool.get('magerp.product_category_attribute_options').get_create_option_id(cr, uid, ifield,'page_layout', context=context)
 else:
     att_id = self.pool.get('magerp.product_category_attribute_options').get_create_option_id(cr, uid, 'None','page_layout', context=context)
 result=[('page_layout',att_id)]","result=[('page_layout', record['page_layout'][1] or '')]"
-"mag_1500_erp_attrgrp_2","magento1500","model_magerp_product_attribute_groups","attribute_set_id","in_out","int","result=[('attribute_set_id', ifield)]","result=[('attribute_set_id', record['attribute_set_id'])]"
-"mag_1500_erp_attrgrp_3","magento1500","model_magerp_product_attribute_groups","attribute_group_name","in_out","unicode","result=[('attribute_group_name', ifield)]","result=[('attribute_group_name', record['attribute_group_name'])]"
-"mag_1500_erp_attrgrp_4","magento1500","model_magerp_product_attribute_groups","sort_order","in_out","int","result=[('sort_order', ifield)]","result=[('sort_order', record['sort_order'])]"
-"mag_1500_erp_attrgrp_5","magento1500","model_magerp_product_attribute_groups","default_id","in_out","int","result=[('default_id', ifield)]","result=[('default_id', record['default_id'])]"
-"mag_1500_erp_attrset_1","magento1500","model_magerp_product_attribute_set","attribute_set_id","in_out","int","result=[('magento_id', ifield)]","result=[('attribute_set_id', record['magento_id'])]"
-"mag_1500_erp_attrset_2","magento1500","model_magerp_product_attribute_set","sort_order","in_out","int","result=[('sort_order', ifield)]","result=[('sort_order', record['sort_order'])]"
-"mag_1500_erp_attrset_3","magento1500","model_magerp_product_attribute_set","attribute_set_name","in_out","unicode","result=[('attribute_set_name', ifield)]","result=[('attribute_set_name', record['attribute_set_name'])]"
-"mag_1500_erp_attr_1","magento1500","model_magerp_product_attributes","attribute_code","in_out","unicode","result=[('attribute_code', ifield)]","result=[('code', record['attribute_code'])]"
-"mag_1500_erp_attr_2","magento1500","model_magerp_product_attributes","attribute_id","in_out","int","result=[('magento_id', ifield)]",
-"mag_1500_erp_attr_3","magento1500","model_magerp_product_attributes","frontend_input","in_out","unicode","result=[('frontend_input', ifield)]","result=[('frontend_input', record['frontend_input'])]"
-"mag_1500_erp_attr_4","magento1500","model_magerp_product_attributes","frontend_class","in_out","unicode","result=[('frontend_class', ifield)]","result=[('frontend_class', record['frontend_class'])]"
-"mag_1500_erp_attr_5","magento1500","model_magerp_product_attributes","backend_model","in_out","unicode","result=[('backend_model', ifield)]","result=[('backend_model', record['backend_model'])]"
-"mag_1500_erp_attr_6","magento1500","model_magerp_product_attributes","backend_type","in_out","unicode","result=[('backend_type', ifield)]","result=[('backend_type', record['backend_type'])]"
-"mag_1500_erp_attr_7","magento1500","model_magerp_product_attributes","frontend_label","in_out","unicode","result=[('frontend_label', ifield)]","result=[('frontend_label', record['frontend_label'])]"
-"mag_1500_erp_attr_8","magento1500","model_magerp_product_attributes","is_visible_in_advanced_search","in_out","unicode","result=[('is_visible_in_advanced_search', bool(eval(ifield)))]","result=[('is_visible_in_advanced_search', record['is_visible_in_advanced_search'])]"
-"mag_1500_erp_attr_9","magento1500","model_magerp_product_attributes","is_global","in_out","unicode","result=[('is_global', bool(eval(ifield)))]","result=[('is_global', record['is_global'])]"
-"mag_1500_erp_attr_10","magento1500","model_magerp_product_attributes","is_filterable","in_out","unicode","result=[('is_filterable', bool(eval(ifield)))]","result=[('is_filterable', record['is_filterable'])]"
-"mag_1500_erp_attr_11","magento1500","model_magerp_product_attributes","is_comparable","in_out","unicode","result=[('is_comparable', bool(eval(ifield)))]","result=[('is_comparable', record['is_comparable'])]"
-"mag_1500_erp_attr_12","magento1500","model_magerp_product_attributes","is_visible","in_out","unicode","result=[('is_visible', bool(eval(ifield)))]","result=[('is_visible', record['is_visible'])]"
-"mag_1500_erp_attr_13","magento1500","model_magerp_product_attributes","is_searchable","in_out","unicode","result=[('is_searchable', bool(eval(ifield)))]","result=[('is_searchable', record['is_searchable'])]"
-"mag_1500_erp_attr_14","magento1500","model_magerp_product_attributes","is_user_defined","in_out","unicode","result=[('is_user_defined', bool(eval(ifield)))]","result=[('is_user_defined', record['is_user_defined'])]"
-"mag_1500_erp_attr_15","magento1500","model_magerp_product_attributes","is_configurable","in_out","unicode","result=[('is_configurable', bool(eval(ifield)))]","result=[('is_configurable', record['is_configurable'])]"
-"mag_1500_erp_attr_16","magento1500","model_magerp_product_attributes","is_visible_on_front","in_out","unicode","result=[('is_visible_on_front', bool(eval(ifield)))]","result=[('is_visible_on_front', record['is_visible_on_front'])]"
-"mag_1500_erp_attr_17","magento1500","model_magerp_product_attributes","is_used_for_price_rules","in_out","unicode","result=[('is_used_for_price_rules', bool(eval(ifield)))]","result=[('is_used_for_price_rules', record['is_used_for_price_rules'])]"
-"mag_1500_erp_attr_18","magento1500","model_magerp_product_attributes","is_unique","in_out","unicode","result=[('is_unique', bool(eval(ifield)))]","result=[('is_unique', record['is_unique'])]"
-"mag_1500_erp_attr_19","magento1500","model_magerp_product_attributes","is_required","in_out","unicode","result=[('is_required', bool(eval(ifield)))]","result=[('is_required', record['is_required'])]"
-"mag_1500_erp_attr_20","magento1500","model_magerp_product_attributes","position","in_out","int","result=[('position', ifield)]","result=[('position', record['position'])]"
-"mag_1500_erp_attr_21","magento1500","model_magerp_product_attributes","attribute_set_info","in_out","unicode","result=[('attribute_set_info', ifield)]","result=[('attribute_set_info', record['attribute_set_info'])]"
-"mag_1500_erp_attr_22","magento1500","model_magerp_product_attributes","default_value","in_out","unicode","result=[('default_value', ifield)]","result=[('default_value', record['default_value'])]"
-"mag_1500_erp_attr_23","magento1500","model_magerp_product_attributes","note","in_out","unicode","result=[('note', ifield)]","result=[('note', record['note'])]"
-"mag_1500_erp_attr_24","magento1500","model_magerp_product_attributes","entity_type_id","in_out","int","result=[('entity_type_id', ifield)]","result=[('entity_type_id', record['entity_type_id'])]"
-"mag_1500_erp_attr_25","magento1500","model_magerp_product_attributes","apply_to","in_out","unicode","result=[('apply_to', str(ifield))]","result=[('apply_to', eval(record['%s']))]"
-"mag_1500_erp_prd_1","magento1500","product.model_product_product","url_key","in_out","unicode","result=[('x_magerp_url_key',ifield)]","if context.get('export_url', False) :
+mag_1500_erp_attrgrp_2,magento1500,model_magerp_product_attribute_groups,attribute_set_id,,in_out,function,int,,"result=[('attribute_set_id', ifield)]","result=[('attribute_set_id', record['attribute_set_id'])]"
+mag_1500_erp_attrgrp_3,magento1500,model_magerp_product_attribute_groups,attribute_group_name,,in_out,function,unicode,,"result=[('attribute_group_name', ifield)]","result=[('attribute_group_name', record['attribute_group_name'])]"
+mag_1500_erp_attrgrp_4,magento1500,model_magerp_product_attribute_groups,sort_order,,in_out,function,int,,"result=[('sort_order', ifield)]","result=[('sort_order', record['sort_order'])]"
+mag_1500_erp_attrgrp_5,magento1500,model_magerp_product_attribute_groups,default_id,,in_out,function,int,,"result=[('default_id', ifield)]","result=[('default_id', record['default_id'])]"
+mag_1500_erp_attrset_1,magento1500,model_magerp_product_attribute_set,attribute_set_id,,in_out,function,int,,"result=[('magento_id', ifield)]","result=[('attribute_set_id', record['magento_id'])]"
+mag_1500_erp_attrset_2,magento1500,model_magerp_product_attribute_set,sort_order,,in_out,function,int,,"result=[('sort_order', ifield)]","result=[('sort_order', record['sort_order'])]"
+mag_1500_erp_attrset_3,magento1500,model_magerp_product_attribute_set,attribute_set_name,,in_out,function,unicode,,"result=[('attribute_set_name', ifield)]","result=[('attribute_set_name', record['attribute_set_name'])]"
+mag_1500_erp_attr_1,magento1500,model_magerp_product_attributes,attribute_code,,in_out,function,unicode,,"result=[('attribute_code', ifield)]","result=[('code', record['attribute_code'])]"
+mag_1500_erp_attr_2,magento1500,model_magerp_product_attributes,attribute_id,,in_out,function,int,,"result=[('magento_id', ifield)]",
+mag_1500_erp_attr_3,magento1500,model_magerp_product_attributes,frontend_input,,in_out,function,unicode,,"result=[('frontend_input', ifield)]","result=[('frontend_input', record['frontend_input'])]"
+mag_1500_erp_attr_4,magento1500,model_magerp_product_attributes,frontend_class,,in_out,function,unicode,,"result=[('frontend_class', ifield)]","result=[('frontend_class', record['frontend_class'])]"
+mag_1500_erp_attr_5,magento1500,model_magerp_product_attributes,backend_model,,in_out,function,unicode,,"result=[('backend_model', ifield)]","result=[('backend_model', record['backend_model'])]"
+mag_1500_erp_attr_6,magento1500,model_magerp_product_attributes,backend_type,,in_out,function,unicode,,"result=[('backend_type', ifield)]","result=[('backend_type', record['backend_type'])]"
+mag_1500_erp_attr_7,magento1500,model_magerp_product_attributes,frontend_label,,in_out,function,unicode,,"result=[('frontend_label', ifield)]","result=[('frontend_label', record['frontend_label'])]"
+mag_1500_erp_attr_8,magento1500,model_magerp_product_attributes,is_visible_in_advanced_search,,in_out,function,unicode,,"result=[('is_visible_in_advanced_search', bool(eval(ifield)))]","result=[('is_visible_in_advanced_search', record['is_visible_in_advanced_search'])]"
+mag_1500_erp_attr_9,magento1500,model_magerp_product_attributes,is_global,,in_out,function,unicode,,"result=[('is_global', bool(eval(ifield)))]","result=[('is_global', record['is_global'])]"
+mag_1500_erp_attr_10,magento1500,model_magerp_product_attributes,is_filterable,,in_out,function,unicode,,"result=[('is_filterable', bool(eval(ifield)))]","result=[('is_filterable', record['is_filterable'])]"
+mag_1500_erp_attr_11,magento1500,model_magerp_product_attributes,is_comparable,,in_out,function,unicode,,"result=[('is_comparable', bool(eval(ifield)))]","result=[('is_comparable', record['is_comparable'])]"
+mag_1500_erp_attr_12,magento1500,model_magerp_product_attributes,is_visible,,in_out,function,unicode,,"result=[('is_visible', bool(eval(ifield)))]","result=[('is_visible', record['is_visible'])]"
+mag_1500_erp_attr_13,magento1500,model_magerp_product_attributes,is_searchable,,in_out,function,unicode,,"result=[('is_searchable', bool(eval(ifield)))]","result=[('is_searchable', record['is_searchable'])]"
+mag_1500_erp_attr_14,magento1500,model_magerp_product_attributes,is_user_defined,,in_out,function,unicode,,"result=[('is_user_defined', bool(eval(ifield)))]","result=[('is_user_defined', record['is_user_defined'])]"
+mag_1500_erp_attr_15,magento1500,model_magerp_product_attributes,is_configurable,,in_out,function,unicode,,"result=[('is_configurable', bool(eval(ifield)))]","result=[('is_configurable', record['is_configurable'])]"
+mag_1500_erp_attr_16,magento1500,model_magerp_product_attributes,is_visible_on_front,,in_out,function,unicode,,"result=[('is_visible_on_front', bool(eval(ifield)))]","result=[('is_visible_on_front', record['is_visible_on_front'])]"
+mag_1500_erp_attr_17,magento1500,model_magerp_product_attributes,is_used_for_price_rules,,in_out,function,unicode,,"result=[('is_used_for_price_rules', bool(eval(ifield)))]","result=[('is_used_for_price_rules', record['is_used_for_price_rules'])]"
+mag_1500_erp_attr_18,magento1500,model_magerp_product_attributes,is_unique,,in_out,function,unicode,,"result=[('is_unique', bool(eval(ifield)))]","result=[('is_unique', record['is_unique'])]"
+mag_1500_erp_attr_19,magento1500,model_magerp_product_attributes,is_required,,in_out,function,unicode,,"result=[('is_required', bool(eval(ifield)))]","result=[('is_required', record['is_required'])]"
+mag_1500_erp_attr_20,magento1500,model_magerp_product_attributes,position,,in_out,function,int,,"result=[('position', ifield)]","result=[('position', record['position'])]"
+mag_1500_erp_attr_21,magento1500,model_magerp_product_attributes,attribute_set_info,,in_out,function,unicode,,"result=[('attribute_set_info', ifield)]","result=[('attribute_set_info', record['attribute_set_info'])]"
+mag_1500_erp_attr_22,magento1500,model_magerp_product_attributes,default_value,,in_out,function,unicode,,"result=[('default_value', ifield)]","result=[('default_value', record['default_value'])]"
+mag_1500_erp_attr_23,magento1500,model_magerp_product_attributes,note,,in_out,function,unicode,,"result=[('note', ifield)]","result=[('note', record['note'])]"
+mag_1500_erp_attr_24,magento1500,model_magerp_product_attributes,entity_type_id,,in_out,function,int,,"result=[('entity_type_id', ifield)]","result=[('entity_type_id', record['entity_type_id'])]"
+mag_1500_erp_attr_25,magento1500,model_magerp_product_attributes,apply_to,,in_out,function,unicode,,"result=[('apply_to', str(ifield))]","result=[('apply_to', eval(record['%s']))]"
+mag_1500_erp_prd_1,magento1500,product.model_product_product,url_key,,in_out,function,unicode,,"result=[('x_magerp_url_key',ifield)]","if context.get('export_url', False) :
     result=[('url_key',record['x_magerp_url_key'])]"
-"mag_1500_erp_prd_2","magento1500","product.model_product_product","name","in_out","unicode","result = [('name',ifield)]","result = [('name',record['name'])]"
-"mag_1500_erp_prd_3","magento1500","product.model_product_product","description","in_out","unicode","result = [('description',ifield)]",
-"mag_1500_erp_prd_4","magento1500","product.model_product_product","short_description","in_out","unicode","result = [('description_sale',ifield)]",
-"mag_1500_erp_prd_5","magento1500","product.model_product_product","sku","in_out","unicode","result = [('magento_sku',ifield), ('default_code',ifield)]",
-"mag_1500_erp_prd_6","magento1500","product.model_product_product","weight","in_out","float","result = [('weight',ifield)]","result = [('weight',record['weight'] or 0)]"
-"mag_1500_erp_prd_7","magento1500","product.model_product_product","categories","in_out","list","categ_ids =[]
+mag_1500_erp_prd_2,magento1500,product.model_product_product,name,,in_out,function,unicode,,"result = [('name',ifield)]","result = [('name',record['name'])]"
+mag_1500_erp_prd_3,magento1500,product.model_product_product,description,,in_out,function,unicode,,"result = [('description',ifield)]",
+mag_1500_erp_prd_4,magento1500,product.model_product_product,short_description,,in_out,function,unicode,,"result = [('description_sale',ifield)]",
+mag_1500_erp_prd_5,magento1500,product.model_product_product,sku,,in_out,function,unicode,,"result = [('magento_sku',ifield), ('default_code',ifield)]",
+mag_1500_erp_prd_6,magento1500,product.model_product_product,weight,,in_out,function,float,,"result = [('weight',ifield)]","result = [('weight',record['weight'] or 0)]"
+mag_1500_erp_prd_7,magento1500,product.model_product_product,categories,,in_out,function,list,,"categ_ids =[]
 if ifield:
     for category_id in ifield:
         categ_ids.append(self.pool.get('product.category').extid_to_oeid(cr, uid, category_id, external_referential_id))
@@ -176,24 +178,24 @@
     if categ_id:
         categ_ids.append(categ_id)
 result=[('categories', categ_ids)]"
-"mag_1500_erp_prd_8","magento1500","product.model_product_product","price","in_out","float","result=[('list_price',ifield)]","result=[]#map later"
-"mag_1500_erp_prd_9","magento1500","product.model_product_product","cost","in_out","float","result=[('standard_price',ifield)]","result = [('cost',record['standard_price'] or 0)]"
-"mag_1500_erp_prd_10","magento1500","product.model_product_product","set","in_out","unicode","result=[('set',self.pool.get('magerp.product_attribute_set').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
-"mag_1500_erp_prd_11","magento1500","product.model_product_product","special_price","in_out","float","result = [('x_magerp_special_price',ifield)]",
-"mag_1500_erp_prd_12","magento1500","product.model_product_product","tier_price","in_out","unicode","result=[]#no mapping by default","result=[]#no mapping by default"
-"mag_1500_erp_prd_13","magento1500","product.model_product_product","minimal_price","in_out","float","result = [('x_magerp_minimal_price',ifield)]","
+mag_1500_erp_prd_8,magento1500,product.model_product_product,price,,in_out,function,float,,"result=[('list_price',ifield)]",result=[]#map later
+mag_1500_erp_prd_9,magento1500,product.model_product_product,cost,,in_out,function,float,,"result=[('standard_price',ifield)]","result = [('cost',record['standard_price'] or 0)]"
+mag_1500_erp_prd_10,magento1500,product.model_product_product,set,,in_out,function,unicode,,"result=[('set',self.pool.get('magerp.product_attribute_set').extid_to_oeid(cr, uid, ifield, external_referential_id))]",
+mag_1500_erp_prd_11,magento1500,product.model_product_product,special_price,,in_out,function,float,,"result = [('x_magerp_special_price',ifield)]",
+mag_1500_erp_prd_12,magento1500,product.model_product_product,tier_price,,in_out,function,unicode,,result=[]#no mapping by default,result=[]#no mapping by default
+mag_1500_erp_prd_13,magento1500,product.model_product_product,minimal_price,,in_out,function,float,,"result = [('x_magerp_minimal_price',ifield)]","
 if record['x_magerp_minimal_price'] and record['x_magerp_minimal_price'] != 0:
     result = [('minimal_price',record['x_magerp_minimal_price'])]
 else:
     result = [('minimal_price',False)]"
-"mag_1500_erp_prd_14","magento1500","product.model_product_product","type_id","in_out","unicode","if ifield:
+mag_1500_erp_prd_14,magento1500,product.model_product_product,type_id,,in_out,function,unicode,,"if ifield:
     product_type_ids  = self.pool.get('magerp.product_product_type').search(cr,uid,[('product_type','=',ifield)])
     if product_type_ids:
         result = [('product_type',ifield)]","if 'product_type' in record and record['product_type']:
     result = [('type_id',record['product_type'])]
 else:
     result = [('type_id','simple')]"
-"mag_1500_erp_prd_15","magento1500","product.model_product_product","websites","in_out","list","websites_ids = []
+mag_1500_erp_prd_15,magento1500,product.model_product_product,websites,,in_out,function,list,,"websites_ids = []
 for ext_id in ifield:
     websites_ids.append(self.pool.get('external.shop.group').extid_to_oeid(cr, uid, ext_id, external_referential_id))
 
@@ -213,29 +215,29 @@
     ext_websites_ids.append(self.pool.get('external.shop.group').oeid_to_extid(cr, uid, oe_id, external_referential_id))
 
 result=[('websites', ext_websites_ids)]"
-"mag_1500_erp_prd_16","magento1500","product.model_product_product","has_options","in","unicode","result =[('x_magerp_has_options',ifield)]",""
-"magento_1500_cst_grp_1","magento1500","base.model_res_partner_category","customer_group_code","in","unicode","result=[('name',ifield)]",
-"magento_1500_cst_grp_3","magento1500","base.model_res_partner_category","tax_class_id","in","int","result=[('tax_class_id',ifield)]",
-"magento_1500_prt_adr_2","magento1500","base.model_res_partner_address","city","in_out","unicode","result=[('city',ifield)]",
-"magento_1500_prt_adr_3","magento1500","base.model_res_partner_address","fax","in_out","unicode","result=[('fax',ifield)]",
-"magento_1500_prt_adr_4","magento1500","base.model_res_partner_address","firstname","in_out","unicode","result = [('name', (data.get('company', False) and (data['company'] + ' ; ') or '') + ifield + ' ' + (data['lastname'] or '')), ('firstname', ifield), ('lastname', (data['lastname'] or ''))]",
-"magento_1500_prt_adr_6","magento1500","base.model_res_partner_address","is_active","in_out","unicode","result=[('active',bool(eval(ifield)))]",
-"magento_1500_prt_adr_7","magento1500","base.model_res_partner_address","country_id","in_out","unicode","result = self.pool.get('res.country').search(cr,uid,[('code','=',ifield)])
+mag_1500_erp_prd_16,magento1500,product.model_product_product,has_options,,in,function,unicode,,"result =[('x_magerp_has_options',ifield)]",
+magento_1500_cst_grp_1,magento1500,base.model_res_partner_category,customer_group_code,,in,function,unicode,,"result=[('name',ifield)]",
+magento_1500_cst_grp_3,magento1500,base.model_res_partner_category,tax_class_id,,in,function,int,,"result=[('tax_class_id',ifield)]",
+magento_1500_prt_adr_2,magento1500,base.model_res_partner_address,city,,in_out,function,unicode,,"result=[('city',ifield)]",
+magento_1500_prt_adr_3,magento1500,base.model_res_partner_address,fax,,in_out,function,unicode,,"result=[('fax',ifield)]",
+magento_1500_prt_adr_4,magento1500,base.model_res_partner_address,firstname,,in_out,function,unicode,,"result = [('name', (data.get('company', False) and (data['company'] + ' ; ') or '') + ifield + ' ' + data['lastname']), ('firstname', ifield), ('lastname', data['lastname'])]",
+magento_1500_prt_adr_6,magento1500,base.model_res_partner_address,is_active,,in_out,function,unicode,,"result=[('active',bool(eval(ifield)))]",
+magento_1500_prt_adr_7,magento1500,base.model_res_partner_address,country_id,,in_out,function,unicode,,"result = self.pool.get('res.country').search(cr,uid,[('code','=',ifield)])
 if result and len(result)==1:
 	result=[('country_id',result[0])]
 else:
 	result=[]
 ",
-"magento_1500_prt_adr_8","magento1500","base.model_res_partner_address","street","in_out","unicode","if ifield:
+magento_1500_prt_adr_8,magento1500,base.model_res_partner_address,street,,in_out,function,unicode,,"if ifield:
 	if len(ifield.split('\n')) ==2 :
 		result = [('street', ifield.split('\n')[0]) , ('street2', ifield.split('\n')[1])]
 	else :
 		result = [('street',ifield.replace('\\n',','))]
 else:
 	result = []",
-"magento_1500_prt_adr_9","magento1500","base.model_res_partner_address","postcode","in_out","unicode","result=[('zip',ifield)]",
-"magento_1500_prt_adr_10","magento1500","base.model_res_partner_address","telephone","in_out","unicode","result=[('phone',ifield)]",
-"magento_1500_prt_adr_11","magento1500","base.model_res_partner_address","region","in_out","unicode","if ifield:
+magento_1500_prt_adr_9,magento1500,base.model_res_partner_address,postcode,,in_out,function,unicode,,"result=[('zip',ifield)]",
+magento_1500_prt_adr_10,magento1500,base.model_res_partner_address,telephone,,in_out,function,unicode,,"result=[('phone',ifield)]",
+magento_1500_prt_adr_11,magento1500,base.model_res_partner_address,region,,in_out,function,unicode,,"if ifield:
 	result = self.pool.get('res.country.state').search(cr,uid,[('name','ilike',ifield)])
 	if result and len(result)==1:
 		result = [('state_id',result[0])]
@@ -243,51 +245,51 @@
 		result=[]
 else:
 	result=[]",
-"magento_1500_prt_adr_13","magento1500","base.model_res_partner_address","customer_id","in_out","int","result=self.pool.get('res.partner').extid_to_oeid(cr,uid,ifield,external_referential_id)
+magento_1500_prt_adr_13,magento1500,base.model_res_partner_address,customer_id,,in_out,function,int,,"result=self.pool.get('res.partner').extid_to_oeid(cr,uid,ifield,external_referential_id)
 if result:
 	result=[('partner_id',result)]
 else:
 	result=[('partner_id',False)]",
-"magento_1500_prt_adr_14","magento1500","base.model_res_partner_address","address_type","in_out","unicode","if ifield=='billing':
+magento_1500_prt_adr_14,magento1500,base.model_res_partner_address,address_type,,in_out,function,unicode,,"if ifield=='billing':
 	result=[('type','invoice')]
 elif ifield=='shipping':
 	result=[('type','delivery')]
 else:
 	result=[]",
-"magento_1500_prt_adr_15","magento1500","base.model_res_partner_address","email","in_out","unicode","result=[('email',ifield)]",
-"magento_1500_prt_adr_16","magento1500","base.model_res_partner_address","prefix","in_out","unicode","if ifield:
+magento_1500_prt_adr_15,magento1500,base.model_res_partner_address,email,,in_out,function,unicode,,"result=[('email',ifield)]",
+magento_1500_prt_adr_16,magento1500,base.model_res_partner_address,prefix,,in_out,function,unicode,,"if ifield:
     title_ids = self.pool.get('res.partner.title').search(cr, uid, [('domain', '=', 'contact'), ('shortcut', '=', ifield)])
     if title_ids:
         title_id = title_ids[0]
     else:
         title_id = self.pool.get('res.partner.title').create(cr, uid, {'domain': 'contact', 'shortcut': ifield, 'name' : ifield})
     result=[('title', title_id)]",
-"magento_1500_prt_2","magento1500","base.model_res_partner","group_id","in_out","int","if ifield:
+magento_1500_prt_2,magento1500,base.model_res_partner,group_id,,in_out,function,int,,"if ifield:
 	result=self.pool.get('res.partner.category').extid_to_oeid(cr,uid,ifield,external_referential_id)
 	if result:
 		result=[('group_id',result)]",
-"magento_1500_prt_3","magento1500","base.model_res_partner","store_id","in_out","int","if ifield:
+magento_1500_prt_3,magento1500,base.model_res_partner,store_id,,in_out,function,int,,"if ifield:
 	result=self.pool.get('magerp.storeviews').extid_to_oeid(cr,uid,ifield,external_referential_id)
 	if result:
 		lang = self.pool.get('magerp.storeviews').browse(cr, uid, result).lang_id
 		result=[('store_id',result),('lang',lang and lang.code or False)]",
-"magento_1500_prt_4","magento1500","base.model_res_partner","website_id","in_out","int","if ifield:
+magento_1500_prt_4,magento1500,base.model_res_partner,website_id,,in_out,function,int,,"if ifield:
 	result=self.pool.get('external.shop.group').extid_to_oeid(cr,uid,ifield,external_referential_id)
 	if result:
 		result=[('website_id',result)]",
-"magento_1500_prt_5","magento1500","base.model_res_partner","created_in","in_out","unicode","result=[('created_in',ifield)]",
-"magento_1500_prt_6","magento1500","base.model_res_partner","created_at","in_out","unicode","result=[('created_at',ifield)]",
-"magento_1500_prt_7","magento1500","base.model_res_partner","updated_at","in_out","unicode","result=[('updated_at',ifield)]",
-"magento_1500_prt_8","magento1500","base.model_res_partner","firstname","in_out","unicode","result = [('name', ifield + ' ' + data['lastname'])]","add_id = self.browse(cr, uid, record['id'])
+magento_1500_prt_5,magento1500,base.model_res_partner,created_in,,in_out,function,unicode,,"result=[('created_in',ifield)]",
+magento_1500_prt_6,magento1500,base.model_res_partner,created_at,,in_out,function,unicode,,"result=[('created_at',ifield)]",
+magento_1500_prt_7,magento1500,base.model_res_partner,updated_at,,in_out,function,unicode,,"result=[('updated_at',ifield)]",
+magento_1500_prt_8,magento1500,base.model_res_partner,firstname,,in_out,function,unicode,,"result = [('name', ifield + ' ' + data['lastname'])]","add_id = self.browse(cr, uid, record['id'])
 fn = add_id.address[0].firstname
 ln = add_id.address[0].lastname
 result=[('firstname', fn), ('lastname', ln)]"
-"magento_1500_prt_10","magento1500","base.model_res_partner","email","in_out","unicode","result=[('emailid',ifield)]",
-"magento_1500_prt_11","magento1500","base.model_res_partner","taxvat","in_out","unicode","if ifield:
+magento_1500_prt_10,magento1500,base.model_res_partner,email,,in_out,function,unicode,,"result=[('emailid',ifield)]",
+magento_1500_prt_11,magento1500,base.model_res_partner,taxvat,,in_out,function,unicode,,"if ifield:
 	result=[('mag_vat',ifield)]
 else:
 	result=[]",
-"magento_1500_prt_12","magento1500","base.model_res_partner","dob","in_out","unicode","if ifield:
+magento_1500_prt_12,magento1500,base.model_res_partner,dob,,in_out,function,unicode,,"if ifield:
 	result =[('mag_birthday',ifield[:10])]
 else:
 	result=[]",

=== modified file 'magentoerpconnect/stock.py'
--- magentoerpconnect/stock.py	2012-03-06 16:09:35 +0000
+++ magentoerpconnect/stock.py	2012-03-15 09:47:04 +0000
@@ -100,22 +100,16 @@
         if context is None: context = {}
         logger = netsvc.Logger()
         conn = context.get('conn_obj', False)
-        carrier = self.pool.get('delivery.carrier').read(cr, uid, carrier_id, ['magento_code', 'magento_tracking_title'], context)
+        carrier = self.pool.get('delivery.carrier').read(cr, uid, carrier_id, ['magento_carrier_code', 'magento_tracking_title'], context)
         
         if self.pool.get('ir.model.fields').search(cr, uid, [('name', '=', 'carrier_tracking_ref'), ('model', '=', 'stock.picking')]): #OpenERP v6 have the field carrier_tracking_ref on the stock_picking but v5 doesn't have it
             carrier_tracking_ref = self.read(cr, uid, id, ['carrier_tracking_ref'], context)['carrier_tracking_ref']
         else:
             carrier_tracking_ref = ''
-
-        # in Magento, the delivery method is something like that:
-        # tntmodule2_tnt_basic
-        # where the first part before the _ is always the carrier code
-        # in this example, the carrier code is tntmodule2
-        carrier_code = carrier['magento_code'].split('_')[0]
             
-        res = conn.call('sales_order_shipment.addTrack', [ext_shipping_id, carrier_code, carrier['magento_tracking_title'] or '', carrier_tracking_ref or ''])
+        res = conn.call('sales_order_shipment.addTrack', [ext_shipping_id, carrier['magento_carrier_code'], carrier['magento_tracking_title'] or '', carrier_tracking_ref or ''])
         if res:
-            logger.notifyChannel('ext synchro', netsvc.LOG_INFO, "Successfully adding a tracking reference to the shipping with OpenERP id %s and ext id %s in external sale system" % (id, ext_shipping_id))       
+            logger.notifyChannel('ext synchro', netsvc.LOG_INFO, "Successfully adding a tracking reference to the shipping with OpenERP id %s and ext id %s in external sale system" % (id, ext_shipping_id))
         return True
 
 stock_picking()

=== modified file 'magentoerpconnect_bundle/product.py'
--- magentoerpconnect_bundle/product.py	2011-07-06 13:50:01 +0000
+++ magentoerpconnect_bundle/product.py	2012-03-28 09:49:00 +0000
@@ -28,11 +28,11 @@
     
     def get_bundle_component(self, cr, uid, ids, context):
         res = {}
-        for product in self.browse(cr, uid, product_read[0], context=context):
+        for product in self.browse(cr, uid, ids, context=context):
             res[product.id] = []
             for product_item_set in product.item_set_ids:
                 for product_item_set_line in product_item_set.item_set_line_ids:
-                    res[product.id] += product_item_set_line.product.id
+                    res[product.id].append(product_item_set_line.product_id.id)
         return res
     
     def action_before_exporting(self, cr, uid, id, product_type, external_referential_ids, defaults, context=None):
@@ -43,7 +43,7 @@
             for id in component_ids:
                 if not self.oeid_to_extid(cr, uid, id, shop.referential_id.id):
                     self.ext_export(cr, uid, [id], external_referential_ids, defaults, context)
-        return super(self, product_product).action_before_exporting(cr, uid, id, product_type, external_referential_ids, defaults, context=context)
+        return super(product_product, self).action_before_exporting(cr, uid, id, product_type, external_referential_ids, defaults, context=context)
     
 
     def add_data_to_create_bundle_product(self, cr, uid, oe_id, data, context=None):

=== modified file 'magentoerpconnect_bundle_split/sale.py'
--- magentoerpconnect_bundle_split/sale.py	2012-02-28 09:34:03 +0000
+++ magentoerpconnect_bundle_split/sale.py	2012-03-27 09:40:33 +0000
@@ -48,12 +48,14 @@
             return super(sale_order, self)._merge_sub_items(cr, uid, product_type,
                                             top_item, child_items, context=context)
 
-    def oe_create(self, cr, uid, vals, data,
-                  external_referential_id, defaults, context):
+    def oe_create(self, cr, uid, vals,
+                  external_referential_id, defaults=None, context=None):
 
         order_id = super(sale_order, self).\
-            oe_create(cr, uid, vals, data,
-                      external_referential_id, defaults, context)
+            oe_create(cr, uid, vals,
+                      external_referential_id,
+                      defaults=defaults,
+                      context=context)
 
         order_line_obj = self.pool.get('sale.order.line')
         order = self.browse(cr, uid, order_id, context=context)

=== added directory 'magentoerpconnect_partner_fiscal_category'
=== added file 'magentoerpconnect_partner_fiscal_category/__init__.py'
--- magentoerpconnect_partner_fiscal_category/__init__.py	1970-01-01 00:00:00 +0000
+++ magentoerpconnect_partner_fiscal_category/__init__.py	2012-03-27 09:51:08 +0000
@@ -0,0 +1,21 @@
+# -*- coding: utf-8 -*-
+##############################################################################
+#
+#    Author: Guewen Baconnier
+#    Copyright 2012 Camptocamp SA
+#
+#    This program is free software: you can redistribute it and/or modify
+#    it under the terms of the GNU Affero General Public License as
+#    published by the Free Software Foundation, either version 3 of the
+#    License, or (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU Affero General Public License for more details.
+#
+#    You should have received a copy of the GNU Affero General Public License
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+##############################################################################
+

=== added file 'magentoerpconnect_partner_fiscal_category/__openerp__.py'
--- magentoerpconnect_partner_fiscal_category/__openerp__.py	1970-01-01 00:00:00 +0000
+++ magentoerpconnect_partner_fiscal_category/__openerp__.py	2012-03-27 09:51:08 +0000
@@ -0,0 +1,54 @@
+# -*- coding: utf-8 -*-
+##############################################################################
+#
+#    Author: Guewen Baconnier
+#    Copyright 2012 Camptocamp SA
+#
+#    This program is free software: you can redistribute it and/or modify
+#    it under the terms of the GNU Affero General Public License as
+#    published by the Free Software Foundation, either version 3 of the
+#    License, or (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU Affero General Public License for more details.
+#
+#    You should have received a copy of the GNU Affero General Public License
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+##############################################################################
+
+{
+    'name': 'Magentoerpconnect Partner Fiscal Category',
+    'version': '1.0',
+    'category': 'Generic Modules',
+    "author" : "Camptocamp",
+    'license': 'AGPL-3',
+    'description': """
+
+Link module between :
+ - Magentoerpconnect
+ - account_fiscal_rules_partner_category
+
+
+Maps the Fiscal Category on the Partners with the Customer Group of Magento
+
+It can thereby be used in fiscal position rules.
+
+account_fiscal_rules_partner_category module can be found
+in lp:c2c-financial-addons branch
+
+""",
+    'images': ['images/magentocoreeditors.png',
+               'images/magentoerpconnect.png', ],
+    "website" : 'https://launchpad.net/magentoerpconnect',
+    'depends': ['magentoerpconnect',
+                'account_fiscal_rules_partner_category', ],
+    'init_xml': [],
+    'update_xml': ['settings/1.3.2.4/external.mappinglines.template.csv',
+                   'settings/1.5.0.0/external.mappinglines.template.csv', ],
+    'demo_xml': [],
+    'installable': True,
+    'auto_install': True,
+}

=== added directory 'magentoerpconnect_partner_fiscal_category/settings'
=== added directory 'magentoerpconnect_partner_fiscal_category/settings/1.3.2.4'
=== added file 'magentoerpconnect_partner_fiscal_category/settings/1.3.2.4/external.mappinglines.template.csv'
--- magentoerpconnect_partner_fiscal_category/settings/1.3.2.4/external.mappinglines.template.csv	1970-01-01 00:00:00 +0000
+++ magentoerpconnect_partner_fiscal_category/settings/1.3.2.4/external.mappinglines.template.csv	2012-03-27 09:51:08 +0000
@@ -0,0 +1,5 @@
+id,type_id:id,model_id:id,external_field,field_id:id,type,evaluation_type,external_type,child_mapping_id:id,in_function,out_function
+magentoerpconnect.magento_1500_prt_2,magentoerpconnect.magento1500,base.model_res_partner,group_id,,in_out,function,int,,"if ifield:
+	result=self.pool.get('res.partner.category').extid_to_oeid(cr,uid,ifield,external_referential_id)
+	if result:
+		result=[('group_id', result), ('fiscal_category_id', result)]",

=== added directory 'magentoerpconnect_partner_fiscal_category/settings/1.5.0.0'
=== added file 'magentoerpconnect_partner_fiscal_category/settings/1.5.0.0/external.mappinglines.template.csv'
--- magentoerpconnect_partner_fiscal_category/settings/1.5.0.0/external.mappinglines.template.csv	1970-01-01 00:00:00 +0000
+++ magentoerpconnect_partner_fiscal_category/settings/1.5.0.0/external.mappinglines.template.csv	2012-03-27 09:51:08 +0000
@@ -0,0 +1,5 @@
+id,type_id:id,model_id:id,external_field,field_id:id,type,evaluation_type,external_type,child_mapping_id:id,in_function,out_function
+magentoerpconnect.magento_1500_prt_2,magentoerpconnect.magento1500,base.model_res_partner,group_id,,in_out,function,int,,"if ifield:
+	result=self.pool.get('res.partner.category').extid_to_oeid(cr,uid,ifield,external_referential_id)
+	if result:
+		result=[('group_id', result), ('fiscal_category_id', result)]",

=== added directory 'magentoerpconnect_payment'
=== added file 'magentoerpconnect_payment/__init__.py'
--- magentoerpconnect_payment/__init__.py	1970-01-01 00:00:00 +0000
+++ magentoerpconnect_payment/__init__.py	2012-03-27 09:40:33 +0000
@@ -0,0 +1,23 @@
+# -*- coding: utf-8 -*-
+##############################################################################
+#
+#    Author: Guewen Baconnier
+#    Copyright 2012 Camptocamp SA
+#
+#    This program is free software: you can redistribute it and/or modify
+#    it under the terms of the GNU Affero General Public License as
+#    published by the Free Software Foundation, either version 3 of the
+#    License, or (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU Affero General Public License for more details.
+#
+#    You should have received a copy of the GNU Affero General Public License
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+##############################################################################
+
+import sale
+import payment_type

=== added file 'magentoerpconnect_payment/__openerp__.py'
--- magentoerpconnect_payment/__openerp__.py	1970-01-01 00:00:00 +0000
+++ magentoerpconnect_payment/__openerp__.py	2012-03-27 09:40:33 +0000
@@ -0,0 +1,61 @@
+# -*- coding: utf-8 -*-
+##############################################################################
+#
+#    Author: Guewen Baconnier
+#    Copyright 2012 Camptocamp SA
+#
+#    This program is free software: you can redistribute it and/or modify
+#    it under the terms of the GNU Affero General Public License as
+#    published by the Free Software Foundation, either version 3 of the
+#    License, or (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU Affero General Public License for more details.
+#
+#    You should have received a copy of the GNU Affero General Public License
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+##############################################################################
+
+
+{'name': 'Magentoerpconnect Payment',
+ 'version': '1.0',
+ 'category': 'Generic Modules',
+ 'author': "Camptocamp",
+ 'license': 'AGPL-3',
+ 'description': """Module to extend the module magentoerpconnect.
+
+It aims to ease the workflow of the payments for the sale orders done on Magento.
+Actually, there is mainly, without deep into details, 2 workflows:
+1. (Pre)-Payments done on Magento (credit card, paypal, ...) with a "need to update" flag.
+2. Payments by cheque or bank, for which we wait a payment, before treat the order with a standard / manual workflow (bank statement / voucher, ...).
+
+With Magentoerpconnect, the pre-payments are fully automatic, OpenERP wait until the payment is done on Magento, then manage its sale order workflow
+(prepaid, postpaid, ...), create and auto-reconcile the payment with the invoice.
+
+It's a mess that the payment done by cheque or other "unsure" payment does not benefit from a so advanced workflow,
+because we also have all the data to automatically create payments and reconcile them.
+
+So, this module adds a button "Magento Payment" to create the payment on Magento once you've received your payment.
+This button also update your order ("need to update") and let it continues its workflow as defined in its Base Sale Payment Type
+exactly as it was a pre-payment.
+
+This allow to have one and only one Magento -> OpenERP payment worlflow.
+
+""",
+ 'images': ['images/magentocoreeditors.png',
+            'images/magentoerpconnect.png', ],
+ 'website': "https://launchpad.net/magentoerpconnect",
+ 'depends': ['magentoerpconnect',
+             'sale',
+             'sale_exceptions'],
+ 'init_xml': [],
+ 'update_xml': ['sale_view.xml',
+                'invoice_view.xml',
+                'payment_type_view.xml'],
+ 'demo_xml': [],
+ 'installable': True,
+ 'auto_install': False
+}

=== added file 'magentoerpconnect_payment/invoice_view.xml'
--- magentoerpconnect_payment/invoice_view.xml	1970-01-01 00:00:00 +0000
+++ magentoerpconnect_payment/invoice_view.xml	2012-03-27 09:40:33 +0000
@@ -0,0 +1,17 @@
+<?xml version="1.0"?>
+<openerp>
+    <data>
+        <record model="ir.ui.view" id="invoice_form_magento_invoice">
+            <field name="name">account.invoice.form.magento.invoice</field>
+            <field name="model">account.invoice</field>
+            <field name="inherit_id" ref="account.invoice_form" />
+            <field name="type">form</field>
+            <field name="arch" type="xml">
+                <field name="move_id" position="after">
+                    <field name="magento_ref"/>
+                </field>
+            </field>
+        </record>
+
+    </data>
+</openerp>

=== added file 'magentoerpconnect_payment/payment_type.py'
--- magentoerpconnect_payment/payment_type.py	1970-01-01 00:00:00 +0000
+++ magentoerpconnect_payment/payment_type.py	2012-03-27 09:40:33 +0000
@@ -0,0 +1,34 @@
+# -*- coding: utf-8 -*-
+##############################################################################
+#
+#    Author: Guewen Baconnier
+#    Copyright 2012 Camptocamp SA
+#
+#    This program is free software: you can redistribute it and/or modify
+#    it under the terms of the GNU Affero General Public License as
+#    published by the Free Software Foundation, either version 3 of the
+#    License, or (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU Affero General Public License for more details.
+#
+#    You should have received a copy of the GNU Affero General Public License
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+##############################################################################
+
+from osv import osv, fields
+
+
+class base_sale_payment_type(osv.osv):
+
+    _inherit = 'base.sale.payment.type'
+
+    _columns = {
+        'allow_magento_manual_invoice':
+            fields.boolean('Allow Manual Creation of Magento Invoice')
+    }
+
+base_sale_payment_type()

=== added file 'magentoerpconnect_payment/payment_type_view.xml'
--- magentoerpconnect_payment/payment_type_view.xml	1970-01-01 00:00:00 +0000
+++ magentoerpconnect_payment/payment_type_view.xml	2012-03-27 09:40:33 +0000
@@ -0,0 +1,22 @@
+<?xml version="1.0" encoding="utf-8"?>
+<openerp>
+    <data>
+
+        <record id="view_base_sale_payment_type_form_pay" model="ir.ui.view">
+            <field name="name">base.sale.payment.type.pay</field>
+            <field name="model">base.sale.payment.type</field>
+            <field name="inherit_id" ref="base_sale_multichannels.view_base_sale_payment_type_form"/>
+            <field name="type">form</field>
+            <field name="arch" type="xml">
+                <data>
+                    <form position="inside">
+                        <separator string="Payment" colspan="4" />
+                        <field name="allow_magento_manual_invoice"/>
+                    </form>
+
+                </data>
+            </field>
+        </record>
+
+    </data>
+</openerp>

=== added file 'magentoerpconnect_payment/sale.py'
--- magentoerpconnect_payment/sale.py	1970-01-01 00:00:00 +0000
+++ magentoerpconnect_payment/sale.py	2012-03-27 09:40:33 +0000
@@ -0,0 +1,126 @@
+# -*- coding: utf-8 -*-
+##############################################################################
+#
+#    Author: Guewen Baconnier
+#    Copyright 2012 Camptocamp SA
+#
+#    This program is free software: you can redistribute it and/or modify
+#    it under the terms of the GNU Affero General Public License as
+#    published by the Free Software Foundation, either version 3 of the
+#    License, or (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU Affero General Public License for more details.
+#
+#    You should have received a copy of the GNU Affero General Public License
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+##############################################################################
+import xmlrpclib
+
+from osv import osv, fields
+from tools.translate import _
+
+
+class sale_order(osv.osv):
+
+    _inherit = 'sale.order'
+
+    _columns = {'magento_ref': fields.char('Magento Invoice ID', size=32),
+                'allow_magento_manual_invoice': fields.related(
+                'base_payment_type_id', 'allow_magento_manual_invoice',
+                type='boolean',
+                string="Allow Manual Creation of Magento Invoice")}
+
+    def _magento_create_invoice(self, cr, uid, order, context=None):
+        shop = order.shop_id
+
+        ctx = context.copy()
+        ctx.update({
+            'shop_id': shop.id,
+            'external_referential_type':
+                shop.referential_id.type_id.name, })
+
+        referential = shop.referential_id
+        connection = referential.external_connection()
+        try:
+            external_invoice = self._create_external_invoice(
+                cr, uid, order, connection, referential.id, context=ctx)
+        except xmlrpclib.Fault, magento_error:
+            # TODO: in case of error on Magento because the invoice has
+            # already been created, get the invoice number
+            # and store it in magento_ref
+            raise osv.except_osv(
+                _('Error'), _("Error on Magento on the invoice creation "
+                              "for order %s :\n" \
+                              "%s" % (order.name, magento_error)))
+        self.write(
+            cr, uid, order.id,
+            {'magento_ref': external_invoice},
+            context=context)
+        cr.commit()
+
+        self._check_need_to_update_single(
+            cr, uid, order, connection, context=ctx)
+        return True
+
+    def button_magento_create_invoice(self, cr, uid, ids, context=None):
+        order = self.browse(cr, uid, ids[0], context=context)
+        if order.state != 'draft':
+            raise osv.except_osv(
+                _('Error'), _('This order is not a quotation.'))
+
+        if not order.is_magento:
+            raise osv.except_osv(
+                _('Error'), _('This is not a Magento sale order.'))
+
+        if not order.base_payment_type_id:
+            raise osv.except_osv(
+                _('Error'), _('This order has no external '
+                              'payment type settings.'))
+
+        if not order.base_payment_type_id.allow_magento_manual_invoice:
+            raise osv.except_osv(
+                _('Error'), _(
+                    "Manual creation of the invoice on Magento "
+                    "is forbidden for external payment : %s" %
+                    order.ext_payment_method))
+
+        # sale_exceptions module methods
+        # in order to check if the order is valid
+        # before create the invoice on magento
+        # it maybe has something to correct
+        exception_ids = self.detect_exceptions(
+            cr, uid, [order.id], context=context)
+        if exception_ids:
+            return self._popup_exceptions(
+                cr, uid, order.id,  context=context)
+
+        self._magento_create_invoice(cr, uid, order, context=context)
+        return True
+
+    def _prepare_invoice(self, cr, uid, order, lines, context=None):
+        """Prepare the dict of values to create the new invoice for a
+           sale order. This method may be overridden to implement custom
+           invoice generation (making sure to call super() to establish
+           a clean extension chain).
+
+           Inherited in order to:
+           Update the Magento invoice id because the invoice has been
+           created from the sale order and it is stored on the sale order
+           first.
+
+           :param browse_record order: sale.order record to invoice
+           :param list(int) lines: list of invoice line IDs that must be
+                                   attached to the invoice
+           :return: dict of value to create() the invoice
+        """
+        vals = super(sale_order, self)._prepare_invoice(
+            cr, uid, order, lines, context=context)
+        if order.magento_ref:
+            vals['magento_ref'] = order.magento_ref
+        return vals
+
+sale_order()

=== added file 'magentoerpconnect_payment/sale_view.xml'
--- magentoerpconnect_payment/sale_view.xml	1970-01-01 00:00:00 +0000
+++ magentoerpconnect_payment/sale_view.xml	2012-03-27 09:40:33 +0000
@@ -0,0 +1,25 @@
+<?xml version="1.0"?>
+<openerp>
+    <data>
+        <record model="ir.ui.view" id="view_order_form_magento_invoice">
+            <field name="name">sale.order.form.magento.invoice</field>
+            <field name="model">sale.order</field>
+            <field name="inherit_id" ref="sale_exceptions.view_order_form" />
+            <field name="type">form</field>
+            <field name="arch" type="xml">
+                <button name="button_order_confirm" position="before">
+                    <field name="allow_magento_manual_invoice" invisible="True"/>
+                    <button name="button_magento_create_invoice"
+                            string="Create Invoice on Magento"
+                            type="object"
+                            attrs="{'invisible': ['|', '|', '|',
+                                                  ('is_magento', '=', False),
+                                                  ('state', '!=', 'draft'),
+                                                  ('base_payment_type_id', '=', False),
+                                                  ('allow_magento_manual_invoice', '=', False)]}"
+                            icon="gtk-go-forward" />
+                </button>
+            </field>
+        </record>
+    </data>
+</openerp>

